import { Notifications } from "./entities/platform-users/UserDetails/Notifications";
import { Route, Switch } from "react-router";
import Dashboard from "./components/Dashboard";
import Header from "./components/Header";
import React, { lazy } from "react";
import Sidebar from "./components/Sidebar";
import styled from "@emotion/styled";

const AdminHome = lazy(() =>
  import(
    /*webpackPrefetch: true, webpackChunkName: "admin_home" */ "./entities/admin"
  )
);
const EventsPropertyHome = lazy(() =>
  import(
    /*webpackPrefetch: true, webpackChunkName: "events_property_home" */ "./entities/events-property"
  )
);
const EventsUserHome = lazy(() =>
  import(
    /*webpackPrefetch: true, webpackChunkName: "events_user_home" */ "./entities/events-user"
  )
);
const MaintenanceHome = lazy(() =>
  import(
    /*webpackPrefetch: true, webpackChunkName: "maintenance_home" */ "./entities/maintenance"
  )
);
const OffersHome = lazy(() =>
  import(
    /*webpackPrefetch: true, webpackChunkName: "offers_home" */ "./entities/offers"
  )
);
const PaymentsHome = lazy(() =>
  import(
    /*webpackPrefetch: true, webpackChunkName: "payments_home" */ "./entities/payments/List"
  )
);
const PlatformUsersHome = lazy(() =>
  import(
    /*webpackPrefetch: true, webpackChunkName: "platform_users_home" */ "./entities/platform-users"
  )
);
const PropertyHome = lazy(() =>
  import(
    /*webpackPrefetch: true, webpackChunkName: "property_home" */ "./entities/listing"
  )
);

const AccountStatement = lazy(() =>
  import(
    /*webpackPrefetch: true, webpackChunkName: "account_statement" */ "./entities/payments/AccountStatement/index"
  )
);
const InvitationsHome = lazy(() =>
  import(
    /*webpackPrefetch: true, webpackChunkName: "invitations_home" */ "./entities/invitations"
  )
);
const InvoiceDetails = lazy(() =>
  import(
    /*webpackPrefetch: true, webpackChunkName: "invoice_details" */ "./entities/payments/Invoices/View"
  )
);
const Invoices = lazy(() =>
  import(
    /*webpackPrefetch: true, webpackChunkName: "invoices" */ "./entities/payments/Invoices"
  )
);
const Mortgages = lazy(() =>
  import(
    /*webpackPrefetch: true, webpackChunkName: "mortgages" */ "./entities/mortgages"
  )
);
const ProductsPage = lazy(() =>
  import(
    /*webpackPrefetch: true, webpackChunkName: "products_page" */ "./entities/products"
  )
);
const SystemNotifications = lazy(() =>
  import(
    /*webpackPrefetch: true, webpackChunkName: "transaction_details" */ "./entities/notifications"
  )
);
const TransactionDetails = lazy(() =>
  import(
    /*webpackPrefetch: true, webpackChunkName: "transaction_details" */ "./entities/payments/AccountStatement/Transaction"
  )
);

const Tenancies = lazy(() =>
  import(
    /*webpackPrefetch: true, webpackChunkName: "tenancies" */ "./entities/tenancies"
  )
);

const AdvancedRentPage = lazy(() =>
  import(
    /*webpackPrefetch: true, webpackChunkName: "advanced_rent" */ "./entities/advanced-rent-requests"
  )
);

// eslint-disable-next-line @typescript-eslint/no-unused-vars
const ScheduledPayment = lazy(() =>
  import(
    /*webpackPrefetch: true, webpackChunkName: "scheduled_payment" */ "./entities/payments/AdvancedRent/ScheduledPayment"
  )
);

const PropertyPayments = lazy(() =>
  import(
    /*webpackPrefetch: true, webpackChunkName: "property_payments" */ "./entities/payments/PropertyPayments"
  )
);

const Comments = lazy(() =>
  import(
    /*webpackPrefetch: true, webpackChunkName: "comments" */ "./entities/comments"
  )
);

const UnmatchedTransactions = lazy(() =>
  import(
    /*webpackPrefetch: true, webpackChunkName: "unmatched_transactions" */ "./entities/unmatched-transactions"
  )
);

const OverduePayments = lazy(() =>
  import(
    /*webpackPrefetch: true, webpackChunkName: "overdue_payments" */ "./entities/overdue-payments"
  )
);

const PayoutsMade = lazy(() =>
  import(
    /*webpackPrefetch: true, webpackChunkName: "payouts_made" */ "./entities/payouts-made"
  )
);

export type AppProps = {};
const App: React.FC<AppProps> = () => {
  return (
    <Main>
      <Header />
      <Sidebar />
      <Content>
        <Switch>
          <Route component={Dashboard} exact path="/" />
          <Route component={AdminHome} path="/admin" />
          <Route component={PropertyHome} path="/listing" />
          <Route component={OffersHome} path="/offers" />
          <Route component={PlatformUsersHome} path="/users" />
          <Route component={Notifications} path="/re-engagement" />
          <Route component={PaymentsHome} path="/payments" />
          <Route component={InvoiceDetails} path="/invoices/details" />
          <Route component={Invoices} path="/invoices" />
          <Route component={Tenancies} path="/tenancies" />
          <Route component={OverduePayments} path="/overdue-payments" />
          <Route
            component={UnmatchedTransactions}
            path="/unmatched-transactions"
          />
          <Route component={PayoutsMade} path="/payouts-made" />
          <Route
            component={TransactionDetails}
            path={`/statement/:transactionId`}
          />
          <Route component={AccountStatement} path="/statement" />
          <Route component={AdvancedRentPage} path="/advanced" />
          <Route
            component={PropertyPayments}
            path="/property-payments/:propertyId"
          />
          <Route component={MaintenanceHome} path="/maintenances" />
          <Route component={EventsPropertyHome} path="/events-property" />
          <Route component={EventsUserHome} path="/events-user" />
          <Route component={InvitationsHome} path="/invitations" />
          <Route component={ProductsPage} path="/products" />
          <Route component={Mortgages} path="/mortgages-lead-list" />
          <Route component={SystemNotifications} path="/notifications" />
          <Route component={Comments} path="/comments" />
        </Switch>
      </Content>
    </Main>
  );
};

const Main = styled.div`
  position: realtive;
  left: 0;
  top: 0;
  width: 100%;
  min-height: 100vh;
`;
const Content = styled.div`
  position: absolute;
  top: 60px;
  left: 280px;
  right: 0;
  bottom: 0;
  overflow: auto;
  overflow-y: scroll;
  padding: 40px 40px 0;
`;

export default App;
