import { Field, Form } from "react-final-form";
import { useMutation } from "react-apollo";
import React from "react";

import { CheckboxToggle } from "../../ui/molecules/CheckboxToggle";

import { GetProperty_admin_Property } from "../../entities/listing/graphql/queries/__generated__/GetProperty";
import {
  UpdateProperyIsArchivedVariables,
  UpdateProperyIsArchived_admin_updateProperty,
} from "../../entities/listing/graphql/mutations/__generated__/UpdateProperyIsArchived";
import UpdateProperyIsArchived from "../../entities/listing/graphql/mutations/UpdateProperyIsArchived.graphql";

import css from "./index.module.css";

export interface ArchiveProps {
  property: GetProperty_admin_Property;
}

interface FormValues {
  is_archived?: boolean;
}

const Archive: React.FC<ArchiveProps> = ({ property }) => {
  const [updateProperyIsArchived, { loading }] = useMutation<
    UpdateProperyIsArchived_admin_updateProperty,
    UpdateProperyIsArchivedVariables
  >(UpdateProperyIsArchived);

  const initialValues: FormValues = {
    is_archived: !!property.is_archived,
  };

  const handleSubmit = React.useCallback(
    ({ is_archived = false }: FormValues) => {
      updateProperyIsArchived({ variables: { is_archived, id: property.id } });
    },
    [property.id, updateProperyIsArchived]
  );

  return (
    <div className={css.container}>
      <Form<FormValues>
        initialValues={initialValues}
        onSubmit={handleSubmit}
        render={({ form, submitting }) => (
          <Field
            component={CheckboxToggle}
            data-testid="toggle-archived"
            disabled={loading || submitting}
            labelText="Archived"
            name="is_archived"
            onChange={(e) => {
              form.change("is_archived", e.target.checked);
              form.submit();
            }}
            type="checkbox"
          />
        )}
      />
    </div>
  );
};

export default Archive;
