import {
  AdminDetails,
  AdminDetailsVariables,
} from "../../entities/admin/graphql/queries/__generated__/AdminDetails";
import { Query } from "react-apollo";
import { UserFormRow } from "../../ui/atoms/UserForm";
import { UserItemName, UserItemValue } from "../../ui/atoms/UserCard";
import { format } from "date-fns";
import { oc } from "ts-optchain";
import GET_ADMIN from "../../entities/admin/graphql/queries/Admin.graphql";
import React from "react";
import SystemError from "../../ui/atoms/SystemError";

type Props = {
  id: string;
  date: string;
};

const FormAsideAdminUser = (props: Props) => (
  <Query<AdminDetails, AdminDetailsVariables>
    query={GET_ADMIN}
    variables={{ id: props.id }}
  >
    {({ error, loading, data }) => {
      if (error) {
        return <SystemError error={error} />;
      } else if (loading) {
        return <>loading...</>;
      }

      const admin = oc(data).admin.Admin(null);

      if (!admin) {
        return null;
      }

      return (
        <>
          <UserFormRow>
            <UserItemName>Verified by:</UserItemName>
            <UserItemValue>
              {oc(admin).details.first_name("")}{" "}
              {oc(admin).details.last_name("")}
            </UserItemValue>
          </UserFormRow>
          <UserFormRow>
            <UserItemName>Timestamp</UserItemName>
            <UserItemValue>
              {props.date
                ? format(new Date(props.date), "dd.MM.yyyy HH:mm:ss")
                : " - - - "}
            </UserItemValue>
          </UserFormRow>
        </>
      );
    }}
  </Query>
);

export default FormAsideAdminUser;
