import { AuthTos } from "./graphql/queries/__generated__/AuthTos";
import { CreateAdminVariables } from "./graphql/mutations/__generated__/CreateAdmin";
import { Field, Form } from "react-final-form";
import { InputFieldTouched } from "../../ui/molecules/InputField";
import { Link } from "react-router-dom";
import { PrimaryButton, SecondaryButton } from "../../ui/atoms/Button";
import {
  UserForm,
  UserFormAction,
  UserFormGroup,
  UserFormOverlay,
  UserFormRow,
  UserFormWrapper,
} from "../../ui/atoms/UserForm";
import {
  composeValidators,
  required,
  validEmail,
  validUkNumber,
} from "../../util/validations";
import { graphql, withApollo } from "react-apollo";
import { oc } from "ts-optchain";
import ADMIN_CREATE from "./graphql/mutations/CreateAdmin.graphql";
import AUTH_TOS from "./graphql/queries/AuthTos.graphql";
import PasswordField from "../../ui/molecules/PasswordField";
import React, { Component } from "react";

type State = {};
type Props = {
  client: any;
  auth_tos: AuthTos & {};
  history: any;
};

class AddAdmin extends Component<Props, State> {
  handleSubmit = ({ password, ...rest }) => {
    const { auth_tos, client, history } = this.props;

    const variables: CreateAdminVariables = {
      admin_site: true,
      account: {
        ...rest,
        admin: true,
        block: false,
      },
      tos_accepted: oc(auth_tos).auth.tos.version(),
      password,
    };

    return client
      .mutate({
        mutation: ADMIN_CREATE,
        variables,
      })
      .then((data) => {
        if (oc(data).data.admin.createAdmin.id()) {
          history.push("/admin");
        }
      });
  };

  render() {
    return (
      <UserForm>
        <h2>Add Admin User</h2>

        <UserFormWrapper>
          <Form
            onSubmit={this.handleSubmit}
            render={({ handleSubmit, submitting, valid }) => (
              <form onSubmit={handleSubmit}>
                {submitting && <UserFormOverlay />}
                <UserFormGroup>
                  <UserFormRow>
                    <label htmlFor="details.first_name">First name</label>
                    <Field
                      autoComplete="first_name"
                      component={InputFieldTouched}
                      name="details.first_name"
                      validate={required("First name is require field")}
                    />
                  </UserFormRow>
                  <UserFormRow>
                    <label htmlFor="details.last_name">Last name</label>
                    <Field
                      autoComplete="last_name"
                      component={InputFieldTouched}
                      name="details.last_name"
                      validate={required("Last name is require field")}
                    />
                  </UserFormRow>
                  <UserFormRow>
                    <label htmlFor="password">Password</label>
                    <Field
                      autoComplete="password"
                      component={PasswordField}
                      name="password"
                      textHint="Must change password after login"
                      validate={required("Password is require field")}
                    />
                  </UserFormRow>
                </UserFormGroup>
                <UserFormGroup>
                  <h3>Contact details</h3>
                  <UserFormRow>
                    <label htmlFor="contact.email_primary">Email</label>
                    <Field
                      autoComplete="email_primary"
                      component={InputFieldTouched}
                      name="contact.email_primary"
                      validate={composeValidators(
                        required("First name is require field"),
                        validEmail()
                      )}
                    />
                  </UserFormRow>
                  <UserFormRow>
                    <label htmlFor="contact.email_primary">Phone</label>
                    <Field
                      autoComplete="email_primary"
                      component={InputFieldTouched}
                      name="contact.phone_primary"
                      validate={composeValidators(
                        required("Phone number is require field"),
                        validUkNumber()
                      )}
                    />
                  </UserFormRow>
                </UserFormGroup>
                <UserFormAction>
                  <Link className="link-button" to="/admin">
                    <SecondaryButton type="button">Cancel</SecondaryButton>
                  </Link>

                  <PrimaryButton disabled={submitting || !valid} type="submit">
                    Create
                  </PrimaryButton>
                </UserFormAction>
              </form>
            )}
          />
        </UserFormWrapper>
      </UserForm>
    );
  }
}
export default withApollo<Props>(
  graphql<Props>(AUTH_TOS, { name: "auth_tos" })(AddAdmin)
);
