import { Link } from "react-router-dom";
import {
  SetAdmin,
  SetAdminVariables,
} from "./graphql/mutations/__generated__/SetAdmin";
import {
  SetAdminInvoice,
  SetAdminInvoiceVariables,
} from "./graphql/mutations/__generated__/SetAdminInvoice";
import {
  SetAdminOffer,
  SetAdminOfferVariables,
} from "./graphql/mutations/__generated__/SetAdminOffer";
import { StatusActive, StatusBlock } from "../../ui/atoms/Status";
import { Td, Tr } from "../../ui/atoms/Table";
import { useMutation } from "react-apollo";
import EmailLink from "../../ui/atoms/EmailLink";
import ListAction from "../../ui/atoms/ListAction";
import React from "react";
import SET_ADMIN from "./graphql/mutations/SetAdmin.graphql";
import SET_ADMIN_INVOICE from "./graphql/mutations/SetAdminInvoice.graphql";
import SET_ADMIN_OFFER from "./graphql/mutations/SetAdminOffer.graphql";

type DetailsProps = {
  first_name: string;
  last_name: string;
};
type ContactProps = {
  email_primary: string;
  phone_primary: string;
};
type ListItemProps = {
  adminId: string;
  details: DetailsProps;
  contact: ContactProps;
  block: boolean;
  canAssign?: boolean;
  propertyId?: string;
  offerId?: string;
  invoiceId?: string;
  setModalVisibility?: (open: boolean) => void;
};

const ListItem = ({
  adminId,
  details,
  contact,
  block,
  canAssign = false,
  propertyId,
  offerId,
  invoiceId,
  setModalVisibility,
}: ListItemProps) => {
  const [setAdmin] = useMutation<SetAdmin, SetAdminVariables>(SET_ADMIN, {
    refetchQueries: ["GetProperty"],
  });

  const [setAdminOffer] = useMutation<SetAdminOffer, SetAdminOfferVariables>(
    SET_ADMIN_OFFER,
    {
      refetchQueries: ["GetOffer"],
    }
  );

  const [setAdminInvoice] = useMutation<
    SetAdminInvoice,
    SetAdminInvoiceVariables
  >(SET_ADMIN_INVOICE, {
    refetchQueries: ["PaymentsGetInvoice"],
  });

  const handleSetAdmin = () => {
    if (propertyId) {
      setAdmin({
        variables: {
          admin: adminId,
          property: propertyId,
        },
      }).then(() => {
        setModalVisibility && setModalVisibility(false);
      });
    } else if (offerId) {
      setAdminOffer({
        variables: {
          admin: adminId,
          offer: offerId,
        },
      }).then(() => {
        setModalVisibility && setModalVisibility(false);
      });
    } else if (invoiceId) {
      setAdminInvoice({
        variables: {
          admin: adminId,
          invoice_id: invoiceId,
        },
      }).then(() => {
        setModalVisibility && setModalVisibility(false);
      });
    }
  };

  return (
    <Tr key={adminId}>
      <Td>
        {details.first_name}&nbsp;
        {details.last_name}
      </Td>
      <Td>
        <EmailLink href={`mailto:${contact.email_primary}`}>
          {contact.email_primary}
        </EmailLink>
      </Td>
      <Td>{contact.phone_primary}</Td>
      <Td>
        {block ? (
          <StatusBlock>Blocked</StatusBlock>
        ) : (
          <StatusActive>Active</StatusActive>
        )}
      </Td>
      <Td>
        {canAssign ? (
          <ListAction onClick={handleSetAdmin} text={"Assign"} />
        ) : (
          <Link className="link" to={`/admin/${adminId}/edit`}>
            View
          </Link>
        )}
      </Td>
    </Tr>
  );
};

export default ListItem;
