import { AuthContext } from "./AuthContext";
import { SecondaryButton } from "../../ui/atoms/Button";
import { withApollo } from "react-apollo";
import AdminLogout from "./graphql/mutation/logout.graphql";
import Cookies from "js-cookie";
import React from "react";

const Logout = (props) => {
  const handleLogout = (logOut: Function | void): void => {
    props.client
      .mutate({
        mutation: AdminLogout,
      })
      .then(
        () => {
          Cookies.remove("accessToken");
          window.localStorage.removeItem("adminId");
          logOut && logOut();
        },
        () => {}
      );
  };

  return (
    <AuthContext.Consumer>
      {({ logOut }) => (
        <>
          <SecondaryButton onClick={() => handleLogout(logOut)}>
            Logout
          </SecondaryButton>
        </>
      )}
    </AuthContext.Consumer>
  );
};

export default withApollo(Logout);
