import { AllComments_admin_allComments_comments_user } from "./graphql/__generated__/AllComments";
import { ButtonsGroup } from "../../ui/atoms/UserForm";
import { Modal } from "../../ui/molecules/Modal";
import { PrimaryButton, SecondaryButton } from "../../ui/atoms/Button";
import { Td, Tr } from "../../ui/atoms/Table";
import React, { useCallback, useMemo, useState } from "react";
import axios from "axios";
import format from "date-fns/format";

const { REACT_APP_VHOST, REACT_APP_WORDPRESS_URL } = process.env;

type WPPost = {
  id: string;
  link: string;
};

export const fetchPost = (postId: string | number): Promise<WPPost> =>
  axios
    .get(`${REACT_APP_WORDPRESS_URL}/wp-json/wp/v2/posts/${postId}`)
    .then(({ data }) => data)
    .catch((e) => {
      // eslint-disable-next-line no-console
      console.error(e);
    });

type ListItemProps = {
  commentId: string;
  text: string;
  postId: string;
  user: AllComments_admin_allComments_comments_user | null;
  date: string;
  onDelete: (commentId: string) => void;
};

const ListItem = ({
  commentId,
  text,
  postId,
  user,
  date,
  onDelete,
}: ListItemProps) => {
  const [showModal, setShowModal] = useState(false);

  const handleHideModal = useCallback(() => {
    setShowModal(false);
  }, []);

  const handleShowModal = useCallback(() => {
    setShowModal(true);
  }, []);

  const handleDelete = useCallback(() => {
    onDelete(commentId);
    setShowModal(false);
  }, [commentId, onDelete]);

  const handlePostIdClick = useCallback(() => {
    fetchPost(postId).then((post) => {
      window.open(
        post.link.replace(
          String(REACT_APP_WORDPRESS_URL),
          String(REACT_APP_VHOST)
        )
      );
    });
  }, [postId]);

  const formattedFate = useMemo(
    () => (date ? format(new Date(date), "dd MMM yyyy HH:mm:ss") : "- - -"),
    [date]
  );

  return (
    <Tr key={commentId}>
      <Td>{text}</Td>
      <Td>
        <span className="link" onClick={handlePostIdClick} role="presentation">
          {postId}
        </span>
      </Td>
      <Td>
        {user?.details?.first_name} {user?.details?.last_name}
      </Td>
      <Td>{formattedFate}</Td>
      <Td>
        <span className="link" onClick={handleShowModal} role="presentation">
          Delete
        </span>
        {showModal && (
          <Modal onCancel={handleHideModal} title={"Confirm delete"}>
            <p>
              Are you sure you want to delete a comment with this text:{" "}
              <strong>"{text}"</strong>?
            </p>
            <ButtonsGroup>
              <SecondaryButton onClick={handleHideModal} type="button">
                No
              </SecondaryButton>
              <PrimaryButton onClick={handleDelete}>Yes</PrimaryButton>
            </ButtonsGroup>
          </Modal>
        )}
      </Td>
    </Tr>
  );
};

export default ListItem;
