import { AllInvitations_admin_allInvitations_data } from "./graphql/queries/__generated__/AllInvitations";
import {
  ColumnNarrow,
  ColumnTitle,
  ColumnValue,
  ColumnWide,
  Payment,
  PaymentBody,
  PaymentCreatedAt,
  PaymentDescription,
  PaymentHead,
  StatusConfirmed,
  StatusError,
  StatusSubmitted,
} from "../../ui/atoms/Payment";
import {
  Location,
  LocationVariables,
} from "./graphql/queries/__generated__/Location";
import { ModalWide } from "../../ui/molecules/Modal";
import { Td, Tr } from "../../ui/atoms/Table";
import { User, UserVariables } from "./graphql/queries/__generated__/User";
import { humanizeEnum } from "../../util/enums_converter";
import { invitation_api_InvitationStatusEnum } from "../../globalTypes";
import { useQuery } from "react-apollo";
import Badge from "../../ui/atoms/Badge";
import GET_USER from "./graphql/queries/user.graphql";
import NoBR from "../../ui/atoms/NoBR";
import PROPERTY_LOCATION from "./graphql/queries/Location.graphql";
import React, { FC, useState } from "react";
import format from "date-fns/format";
import styled from "@emotion/styled";
// import GET_USER_RESUORSES from "./graphql/queries/userResourses.graphql";
// import { ReactComponent as ExternalIcon } from "./externalLink.svg";

type Props = {
  data: AllInvitations_admin_allInvitations_data;
};

const ListItem: FC<Props> = ({ data }) => {
  const [isDetailsVisible, setDetailsVisibility] = useState<boolean>(false);
  const inviterData = useQuery<User, UserVariables>(GET_USER, {
    variables: {
      id: data.inviter_id,
    },
    skip: !data.inviter_id,
  });
  const inviter = inviterData.data?.admin?.User;

  // const inviteeData = useQuery<UserResourses, UserResoursesVariables>(
  //   GET_USER_RESUORSES,
  //   {
  //     variables: {
  //       id: data.invitee_id,
  //     },
  //     skip: !data.invitee_id,
  //   }
  // );
  // const inviteeResourses =
  //   inviteeData.data?.admin?.User?.resources?.owned_properties;

  const locationData = useQuery<Location, LocationVariables>(
    PROPERTY_LOCATION,
    {
      variables: {
        id: data.property_id,
      },
      skip: !data.property_id,
    }
  );
  const location = locationData.data?.admin?.Property?.location;

  return (
    <>
      <Tr>
        <Td colSpan={2}>
          <NoBR>
            {data.created_at
              ? format(new Date(data.created_at), "dd MMM yyyy HH:mm:ss")
              : "- - -"}
          </NoBR>
        </Td>
        <Td colSpan={2}>
          <a
            className="link"
            href={`#/users/${data.inviter_id}/view`}
            rel="noopener noreferrer"
            target="_blank"
          >
            {[inviter?.details?.first_name, inviter?.details?.last_name]
              .filter(Boolean)
              .join(" ")}
          </a>
        </Td>
        <Td colSpan={2}>
          {data.invitee_id ? (
            <a
              className="link"
              href={`/#/users/${data.invitee_id}/view`}
              rel="noopener noreferrer"
              target="_blank"
            >
              {[data.invitee_first_name, data.invitee_last_name]
                .filter(Boolean)
                .join(" ")}
            </a>
          ) : (
            <a
              className="link"
              href={`mailto:${data.invitee_email}`}
              rel="noopener noreferrer"
              target="_blank"
            >
              {data.invitee_email.length > 12
                ? `. . .${data.invitee_email.substr(-12)}`
                : data.invitee_email}
            </a>
          )}
        </Td>
        {/* <Td colSpan={2}>
          {(inviteeResourses ?? []).length > 0 ? (
            <>
              <Badge status="success" style={{ flexWrap: "wrap" }}>
                {(inviteeResourses ?? []).map((propertyId) => (
                  <a
                    key={propertyId}
                    href={`/#/listing/${propertyId}/edit`}
                    rel="noopener noreferrer"
                    style={{ margin: "0 3px", color: "white" }}
                    target="_blank"
                  >
                    <ExternalIcon />
                  </a>
                ))}
              </Badge>
            </>
          ) : (
            <Badge status="danger">Has not</Badge>
          )}
        </Td> */}
        <Td colSpan={2}>
          {data.status ===
          invitation_api_InvitationStatusEnum.INVITATION_STATUS_ACCEPTED ? (
            <Badge status="success">Accepted</Badge>
          ) : data.status ===
            invitation_api_InvitationStatusEnum.INVITATION_STATUS_DECLINED ? (
            <Badge status="danger">Declined</Badge>
          ) : data.status ===
            invitation_api_InvitationStatusEnum.INVITATION_STATUS_PENDING ? (
            <Badge status="warning">Pending</Badge>
          ) : (
            "Unknown"
          )}
        </Td>
        <Td colSpan={2}>
          {data.offer ? (
            <a
              className="link"
              href={`#/offers/${data.offer}/edit`}
              rel="noopener noreferrer"
              target="_blank"
            >
              See offer
            </a>
          ) : (
            "- - -"
          )}
        </Td>
        <Td>
          <span
            className="link"
            onClick={() => setDetailsVisibility(true)}
            role="presentation"
          >
            View
          </span>
        </Td>
      </Tr>

      {isDetailsVisible ? (
        <ModalWide
          onCancel={() => setDetailsVisibility(false)}
          title="Invitation Details"
        >
          <Payment>
            <PaymentHead>
              <PaymentDescription>
                <span
                  className={
                    data.status ===
                    invitation_api_InvitationStatusEnum.INVITATION_STATUS_PENDING
                      ? "text-warning bold"
                      : data.status ===
                        invitation_api_InvitationStatusEnum.INVITATION_STATUS_DECLINED
                      ? "text-danger bold"
                      : data.status ===
                        invitation_api_InvitationStatusEnum.INVITATION_STATUS_ACCEPTED
                      ? "text-success bold"
                      : ""
                  }
                >
                  {data.status ? humanizeEnum(data.status).label : "N/A"}
                </span>
              </PaymentDescription>
              <PaymentCreatedAt>
                {data.created_at
                  ? format(new Date(data.created_at), "dd MMM yyyy HH:mm:ss")
                  : "- - -"}
              </PaymentCreatedAt>
              {data.status ===
              invitation_api_InvitationStatusEnum.INVITATION_STATUS_DECLINED ? (
                <StatusError />
              ) : data.status ===
                invitation_api_InvitationStatusEnum.INVITATION_STATUS_PENDING ? (
                <StatusSubmitted />
              ) : data.status ===
                invitation_api_InvitationStatusEnum.INVITATION_STATUS_ACCEPTED ? (
                <StatusConfirmed />
              ) : null}
            </PaymentHead>
            <PaymentBody>
              <ColumnWide>
                <ColumnTitle>Property address</ColumnTitle>
                <ColumnValue>
                  <a
                    className="link"
                    href={`/#/listing/${data.property_id}/edit`}
                    rel="noopener noreferrer"
                    target="_blank"
                  >
                    <>
                      {[
                        location?.address1,
                        location?.address2,
                        location?.address3,
                        location?.address4,
                      ]
                        .filter(Boolean)
                        .join(", ")}
                      {location?.city ||
                      location?.postcode ||
                      location?.country ? (
                        <div>
                          {[
                            location?.city,
                            location?.postcode,
                            location?.country,
                          ]
                            .filter(Boolean)
                            .join(", ")}
                        </div>
                      ) : null}
                    </>
                  </a>
                </ColumnValue>
              </ColumnWide>
              <ColumnNarrow>
                <ColumnTitle>Sent by</ColumnTitle>
                <ColumnValue>
                  <a
                    className="link"
                    href={`/#/users/${data.inviter_id}/view`}
                    rel="noopener noreferrer"
                    target="_blank"
                  >
                    {[inviter?.details?.first_name, inviter?.details?.last_name]
                      .filter(Boolean)
                      .join(" ")}
                  </a>
                </ColumnValue>
              </ColumnNarrow>

              <ColumnWide>
                <ColumnTitle>Invited</ColumnTitle>
                <ColumnValue>
                  {data.invitee_id ? (
                    <a
                      className="link"
                      href={`/#/users/${data.invitee_id}/view`}
                      rel="noopener noreferrer"
                      target="_blank"
                    >
                      {[data.invitee_first_name, data.invitee_last_name]
                        .filter(Boolean)
                        .join(" ")}
                    </a>
                  ) : (
                    <a
                      className="link"
                      href={`mailto:${data.invitee_email}`}
                      rel="noopener noreferrer"
                      target="_blank"
                    >
                      {data.invitee_email}
                    </a>
                  )}
                </ColumnValue>
              </ColumnWide>
              <ColumnNarrow>
                <ColumnTitle>Expires at</ColumnTitle>
                <ColumnValue>
                  {data.expires_at
                    ? format(new Date(data.expires_at), "dd MMM yyyy HH:mm:ss")
                    : "- - -"}
                </ColumnValue>
              </ColumnNarrow>

              <ColumnFullWidth>
                <ColumnTitle>Message</ColumnTitle>
                <ColumnValue>{data.body || "- - -"}</ColumnValue>
              </ColumnFullWidth>
            </PaymentBody>
          </Payment>
        </ModalWide>
      ) : null}
    </>
  );
};

const ColumnFullWidth = styled(ColumnWide)`
  width: 100%;
  padding-right: 0;
`;

export default ListItem;
