import { AdvancedRent } from "../advanced-rent-requests/AdvancedRent";
import { GetProperty_admin_Property } from "./graphql/queries/__generated__/GetProperty";
import {
  PropertyAddress,
  PropertyCardButtons,
  PropertyCardItem,
  PropertyCardItemTitle,
  PropertyCardItemValue,
  PropertyCardTitle,
  PropertyContent,
  PropertyGrid,
} from "../../ui/atoms/Property";
import { humanizeEnum } from "../../util/enums_converter";
import { oc } from "ts-optchain";
import { propertyAddressFilter, propertyTitleFilter } from "./filters";
import Archive from "../../components/Archive";
import AssignAdminModal from "../admin/AssignAdminModal";
import ClickableText from "../../ui/molecules/ClickableText";
import CopyText from "../../ui/molecules/CopyToClipboard";
import Notes from "../../components/Notes";
import React, { useState } from "react";
import format from "date-fns/format";
import isAfter from "date-fns/isAfter";
import isDate from "date-fns/isDate";

type Props = {
  property: GetProperty_admin_Property;
};

const PropertyCard = ({ property }: Props) => {
  const [modalVisible, setModalVisibility] = useState(false);
  const updatedDate = property.updated_at
    ? property.updated_at
    : property.created_at;
  const changedDate =
    property.admin_verify.publication.verified &&
    isAfter(
      new Date(property.admin_verify.publication.verified_at),
      new Date(updatedDate)
    )
      ? new Date(property.admin_verify.publication.verified_at)
      : new Date(updatedDate);

  const adminInfo = property.people.administrator?.details;
  return (
    <PropertyContent>
      {modalVisible && (
        <AssignAdminModal
          propertyId={oc(property).id("")}
          setModalVisibility={setModalVisibility}
        />
      )}
      {!!property.id && (
        <PropertyCardButtons>
          <Notes propertyId={property.id} title="Property Notes" />
          <Archive property={property} />
          <AdvancedRent propertyId={property.id} />
        </PropertyCardButtons>
      )}
      <PropertyCardTitle>{propertyTitleFilter(property)}</PropertyCardTitle>
      <PropertyAddress>
        {propertyAddressFilter(property.location)}
      </PropertyAddress>
      <PropertyGrid>
        <PropertyCardItem>
          <PropertyCardItemTitle>Status</PropertyCardItemTitle>
          <PropertyCardItemValue>
            <b>{humanizeEnum(property.status).label}</b>
          </PropertyCardItemValue>
        </PropertyCardItem>

        <PropertyCardItem>
          <PropertyCardItemTitle>Property ID</PropertyCardItemTitle>
          <PropertyCardItemValue>
            {`. . . ${(property!.id ? property.id : "").substr(-6)}`}
            <CopyText
              text="Copy ID"
              textForCopy={property!.id ? property.id : ""}
            />
          </PropertyCardItemValue>
        </PropertyCardItem>

        <PropertyCardItem>
          <PropertyCardItemTitle>Last changed</PropertyCardItemTitle>
          <PropertyCardItemValue>
            {updatedDate && isDate(new Date(changedDate))
              ? format(new Date(changedDate), "dd.MM.yyyy")
              : "- - -"}
          </PropertyCardItemValue>
        </PropertyCardItem>

        <PropertyCardItem>
          <PropertyCardItemTitle>REFERENCE NO.</PropertyCardItemTitle>
          <PropertyCardItemValue>
            {property.ivr}
            <CopyText
              text="Copy Ref. NO."
              textForCopy={property!.ivr ? property.ivr : ""}
            />
          </PropertyCardItemValue>
        </PropertyCardItem>
        <PropertyCardItem>
          <PropertyCardItemTitle>ASSIGNED TO</PropertyCardItemTitle>
          <PropertyCardItemValue>
            {adminInfo
              ? `${adminInfo.first_name} ${adminInfo.last_name}`
              : "N/A"}
            <ClickableText
              onClick={() => setModalVisibility(true)}
              text="Reassign"
            />
          </PropertyCardItemValue>
        </PropertyCardItem>
      </PropertyGrid>
    </PropertyContent>
  );
};

export default PropertyCard;
