import {
  StatusAside,
  StatusGroup,
  StatusItem,
  StatusItemName,
  StatusItemUnverified,
  StatusItemVerified,
} from "../../ui/atoms/StatusAside";
import React from "react";
import VerifyContext from "./PropertyEditContext";

const Item = ({
  title,
  isVerified,
}: {
  title: string;
  isVerified: boolean;
}) => (
  <StatusItem>
    <StatusItemName>{title}</StatusItemName>
    {isVerified ? (
      <StatusItemVerified
        data-testid={`property_status_${title.toLowerCase().replace(" ", "_")}`}
        data-testverified="true"
      />
    ) : (
      <StatusItemUnverified
        data-testid={`property_status_${title.toLowerCase().replace(" ", "_")}`}
        data-testverified="false"
      />
    )}
  </StatusItem>
);

const PropertyStatuses = () => (
  <VerifyContext.Consumer>
    {({
      publishedInMashroom,
      publishedInZoopla,
      publishedInRightmove,
      publishedInBoomin,
      addressVerified,
      descriptionVerified,
      documentsVerified,
      feeVerified,
      photosVerified,
    }) => (
      <StatusAside>
        <StatusGroup>
          <Item isVerified={!!addressVerified} title="Address" />
          <Item isVerified={!!descriptionVerified} title="Description" />
          <Item isVerified={!!documentsVerified} title="Documents" />
          <Item isVerified={!!photosVerified} title="Photo" />
          <Item isVerified={!!feeVerified} title="Listing Fee" />
          <Item isVerified={!!publishedInMashroom} title="Mashroom" />
          <Item isVerified={!!publishedInZoopla} title="Zoopla" />
          <Item isVerified={!!publishedInRightmove} title="Rightmove" />
          <Item isVerified={!!publishedInBoomin} title="Boomin" />
        </StatusGroup>
      </StatusAside>
    )}
  </VerifyContext.Consumer>
);

export default PropertyStatuses;
