import { DeleteButton, PrimaryButton } from "../../ui/atoms/Button";
import { ModalConfirm } from "../../ui/molecules/Modal";
import { PropertyAsideButtons } from "../../ui/atoms/Property";
import React, { Component } from "react";
import VerifyContext from "./PropertyEditContext";

type State = {
  showConfirmUpdate: boolean;
  showConfirmReset: boolean;
};
type Props = {
  tabName: string;
  onPhotosOrderUpdate?: () => void;
};

class PropertyVerificationButtons extends Component<Props, State> {
  state: State = {
    showConfirmUpdate: false,
    showConfirmReset: false,
  };

  handleOpenConfirmReset = () =>
    this.setState(() => ({ showConfirmReset: true }));
  handleCloseConfirmReset = () =>
    this.setState(() => ({ showConfirmReset: false }));

  handleOpenConfirmUpdate = () =>
    this.setState(() => ({ showConfirmUpdate: true }));
  handleCloseConfirmUpdate = () =>
    this.setState(() => ({ showConfirmUpdate: false }));

  render() {
    return (
      <VerifyContext.Consumer>
        {({
          handleFormReset,
          somethingWasChanged,
          handleFormSubmit,
          submitting,
          valid,
        }) => {
          const handleConfirmReset = () => {
            this.handleCloseConfirmReset();
            handleFormReset && handleFormReset();
          };
          const handleConfirmUpdate = () => {
            this.handleCloseConfirmUpdate();
            this.props.onPhotosOrderUpdate && this.props.onPhotosOrderUpdate();
            handleFormSubmit && handleFormSubmit();
          };

          return (
            <>
              {this.state.showConfirmReset && (
                <ModalConfirm
                  onCancel={this.handleCloseConfirmReset}
                  onConfirm={handleConfirmReset}
                >
                  <strong>Do you want to reset changes?</strong>
                </ModalConfirm>
              )}
              {this.state.showConfirmUpdate && (
                <ModalConfirm
                  onCancel={this.handleCloseConfirmUpdate}
                  onConfirm={handleConfirmUpdate}
                >
                  <strong>{`Are you sure you want to confirm that property ${this.props.tabName} is correct and was verified?`}</strong>
                </ModalConfirm>
              )}
              <PropertyAsideButtons>
                <PrimaryButton
                  data-testid="property_aside_update_button"
                  disabled={!valid || submitting || !somethingWasChanged}
                  onClick={this.handleOpenConfirmUpdate}
                  type="button"
                >
                  Update
                </PrimaryButton>
                <DeleteButton
                  data-testid="property_aside_discard_changes_button"
                  disabled={!valid || submitting || !somethingWasChanged}
                  onClick={this.handleOpenConfirmReset}
                  type="button"
                >
                  Discard Changes
                </DeleteButton>
              </PropertyAsideButtons>
            </>
          );
        }}
      </VerifyContext.Consumer>
    );
  }
}

export default PropertyVerificationButtons;
