import { property_api_PropertyStatusEnum } from "../../globalTypes";

export const HrefToProperty = `${process.env.REACT_APP_VHOST}/property`;

export const TABS = [
  "Address",
  "Description",
  "Documents",
  "Photo",
  "Listing Fee",
  "Viewings",
  "Bank Details",
  "Publication",
];

export enum ServiceCodes {
  deposit_replacement_fee = "deposit_replacement_fee",
  holding_deposit = "holding_deposit",
  content_insurance = "tenant_content_insurance",
  landlord_check_out = "landlord_check_out",
  landlord_eic_report = "landlord_eic_report",
  landlord_epc_certificate = "landlord_epc_certificate",
  landlord_extra_listing = "landlord_extra_listing",
  landlord_gas_certificate = "landlord_gas_certificate",
  landlord_home_emergency_insurance = "landlord_home_emergency_insurance",
  landlord_inventory_check_in_furnished = "landlord_inventory_check_in_furnished",
  landlord_inventory_furnished = "landlord_inventory_furnished",
  landlord_inventory_unfurnished = "landlord_inventory_unfurnished",
  landlord_inventory = "landlord_inventory",
  landlord_inventory_check_in = "landlord_inventory_check_in",
  landlord_listing_fee = "landlord_listing_fee",
  landlord_photographs_floor_plans = "landlord_photographs_floor_plans",
  landlord_rent_guarantee_insurance = "landlord_rent_guarantee_insurance",
  lanldord_life_insurance = "lanldord_life_insurance",
  landlord_referencing_report = "landlord_referencing_report",
}

export enum DocumentTypeCodes {
  identity = "identity",
  bill = "bill",
  contract = "contract",
  certificate = "certificate",
  maintenance = "maintenance",
  photo = "photo",
  photo_raw = "photo_raw",
  plan = "plan",
  plan_raw = "plan_raw",
  home_emergency_insurance = "home_emergency_insurance",
  inventory = "inventory",
  check_out_report = "check_out_report",
  check_in_report = "check_in_report",
  rent_guarantee_insurance = "rent_guarantee_insurance",
  deposit_registration_certificate = "deposit_registration_certificate",
  life_insurance = "life_insurance",
  referencing_report = "referencing_report",
  contents_insurance = "contents_insurance",
  other = "other",
}

export const DocumentTypeOptions = [
  {
    type_code: DocumentTypeCodes.bill,
    label: "Bill",
  },
  {
    type_code: DocumentTypeCodes.contract,
    label: "Tenancy Contract",
  },
  {
    type_code: DocumentTypeCodes.deposit_registration_certificate,
    label: "Deposit Certificate",
  },
  {
    code: ServiceCodes.landlord_gas_certificate,
    type_code: DocumentTypeCodes.certificate,
    label: "Gas Safety",
  },
  {
    code: ServiceCodes.landlord_eic_report,
    type_code: DocumentTypeCodes.certificate,
    label: "EICR",
  },
  {
    code: ServiceCodes.landlord_epc_certificate,
    type_code: DocumentTypeCodes.certificate,
    label: "EPC",
  },
  {
    code: ServiceCodes.landlord_inventory,
    type_code: DocumentTypeCodes.inventory,
    label: "Inventory Report",
  },
  {
    code: ServiceCodes.landlord_inventory_check_in,
    type_code: DocumentTypeCodes.check_in_report,
    label: "Check-In Report",
  },
  {
    code: ServiceCodes.landlord_check_out,
    type_code: DocumentTypeCodes.check_out_report,
    label: "Check-Out Report",
  },
  {
    type_code: DocumentTypeCodes.identity,
    label: "Identity",
  },
  {
    type_code: DocumentTypeCodes.other,
    label: "Other",
  },
];

export const FilterLastUpdateOptions = [
  { label: "Today", value: "today" },
  { label: "Yesterday", value: "yesterday" },
  { label: "This week", value: "this-week" },
  { label: "Last week", value: "last-week" },
];

export const FilterStatusOptions = [
  { label: "Any", value: "" },
  { label: "Incomplete", value: property_api_PropertyStatusEnum.INCOMPLETE },
  { label: "Verifying", value: property_api_PropertyStatusEnum.VERIFYING },
  { label: "Missing", value: property_api_PropertyStatusEnum.MISSING },
  { label: "Listed", value: property_api_PropertyStatusEnum.LISTED },
  { label: "Amendment", value: property_api_PropertyStatusEnum.AMENDMENT },
  { label: "Rented", value: property_api_PropertyStatusEnum.RENTED },
  { label: "Withdrawn", value: property_api_PropertyStatusEnum.WITHDRAWN },
];

export const listingActions = {
  SET_CURRENT_PAGE: "SET_CURRENT_PAGE",
  SET_SORT_FIELD: "SET_SORT_FIELD",
  SET_SORT_ORDER: "SET_SORT_ORDER",
  SET_SEARCH: "SET_SEARCH",
  SET_POSTCODE: "SET_POSTCODE",
  SET_STATUS: "SET_STATUS",
  SET_UPDATED_AT: "SET_UPDATED_AT",
  SET_IS_ARCHIVED: "SET_IS_ARCHIVED",
  SET_ADMIN_NAME: "SET_ADMIN_NAME",
};
export type ListingInitialState = {
  currentPage: number;
  perPage: number;
  search?: string;
  postcode?: string;
  status?: string | { label: string; value: string };
  updated_at?: string | { label: string; value: string };
  admin_name?: string | { label: string; value: string };
  is_archived?: boolean;
  sortField: string[];
  sortOrder: number;
};
export const listingInitialState: ListingInitialState = {
  currentPage: 1,
  perPage: 25,
  search: "",
  postcode: "",
  status: "",
  updated_at: "",
  admin_name: "",
  is_archived: false,
  sortField: [],
  sortOrder: 1,
};
export enum MOVEIN_DATE {
  MOVEIN_DATE_AS_SOON_AS_POSSIBLE = "As soon as possible",
  MOVEIN_DATE_ONE_TO_TWO_MONTH = "2 to 4 Weeks",
  MOVEIN_DATE_TWO_PLUS_MONTHS = "1 to 2 Months",
  MOVEIN_DATE_TWO_TO_FOUR_WEEKS = "2+ Months",
  UNKNOWN_MOVEIN_DATE = "Unknown movein date",
}
export const FurnitureOptions = [
  { label: "Furnished", value: "PROPERTY_FURNITURE_FURNISHED" },
  { label: "Unfurnished", value: "PROPERTY_FURNITURE_UNFURNISHED" },
  { label: "Partly Furnished", value: "PROPERTY_FURNITURE_PARTLY_FURNISHED" },
  { label: "Unknown", value: "UNKNOWN_PROPERTY_FURNITURE" },
];
export const OutsideSpaceOptions = [
  { label: "Communal Garden", value: "PROPERTY_OUTSIDE_SPACE_COMMUNAL_GARDEN" },
  { label: "None Space", value: "PROPERTY_OUTSIDE_SPACE_NONE" },
  { label: "Private Garden", value: "PROPERTY_OUTSIDE_SPACE_PRIVATE_GARDEN" },
  { label: "Balcony", value: "PROPERTY_OUTSIDE_SPACE_BALCONY" },
  { label: "Terrace", value: "PROPERTY_OUTSIDE_SPACE_TERRACE" },
  { label: "Unknown", value: "UNKNOWN_PROPERTY_OUTSIDE_SPACE" },
];
export const ParkingOptions = [
  { label: "Garage", value: "PROPERTY_PARKING_GARAGE" },
  { label: "Off Street", value: "PROPERTY_PARKING_OFFSTREET" },
  { label: "Residents Parking", value: "PROPERTY_PARKING_RESIDENTS_PARKING" },
  { label: "No Parking", value: "PROPERTY_PARKING_NONE" },
  { label: "Double Garage", value: "PROPERTY_PARKING_DOUBLE_GARAGE" },
  { label: "Unknown", value: "UNKNOWN_PROPERTY_PARKING" },
];
