import {
  UpdatePropertyVariables,
  UpdateProperty_admin_updateProperty_admin_verify_address,
  UpdateProperty_admin_updateProperty_description,
  UpdateProperty_admin_updateProperty_details,
  UpdateProperty_admin_updateProperty_rental,
} from "../graphql/mutations/__generated__/UpdateProperty";

import { GetProperty_admin_Property } from "../graphql/queries/__generated__/GetProperty";
import { document_api_DocumentStateEnum } from "../../../globalTypes";

type UpdateAdminVerifyItemType = Pick<
  UpdateProperty_admin_updateProperty_admin_verify_address,
  "verified"
>;
type UpdateAdminVerifyType = Record<
  "address" | "description" | "fee" | "photos" | "documents",
  UpdateAdminVerifyItemType
>;
type UpdateDescriptionType = Pick<
  UpdateProperty_admin_updateProperty_description,
  "post_headline" | "post_property_pitch"
>;
type UpdateDocumentsType = {
  state: document_api_DocumentStateEnum;
  id: string;
};
type UpdateDetails = Pick<
  UpdateProperty_admin_updateProperty_details,
  "amenity_furniture" | "amenity_outside_space" | "amenity_parking" | "type"
>;
type UpdateRental = Pick<
  UpdateProperty_admin_updateProperty_rental,
  "rental_price" | "tenancy_deposit_insurance"
>;

const updatePropertyFilter = (
  formValues: GetProperty_admin_Property
): UpdatePropertyVariables => {
  const {
    admin_verify,
    location,
    description,
    id,
    documents,
    details,
    rental,
  } = formValues;

  return {
    id,
    admin_verify: {
      address: {
        verified: admin_verify.address.verified,
      },
      description: {
        verified: admin_verify.description.verified,
      },
      documents: {
        verified: admin_verify.documents.verified,
      },
      photos: {
        verified: admin_verify.photos.verified,
      },
      fee: {
        verified: admin_verify.fee.verified,
      },
    },
    location: {
      address1: location.address1,
      address2: location.address2 ?? "",
      address3: location.address3 ?? "",
      postcode: location.postcode,
      city: location.city,
      county: location.county ?? "",
      country: location.country ?? "",
      building: location.building ?? "",
      flat: location.flat ?? "",
      street: location.street,
      gps: {
        latitude: location.gps.latitude,
        longitude: location.gps.longitude,
      },
    },
    description: {
      post_headline: description.post_headline,
      post_property_pitch: description.post_property_pitch,
      post_property_admin_pitch: description.post_property_admin_pitch,
    },
    details: {
      amenity_furniture: details.amenity_furniture,
      amenity_outside_space: details.amenity_outside_space,
      amenity_parking: details.amenity_parking,
      type: details.type,
    },
    documents: (documents ? documents : []).map<UpdateDocumentsType>(
      (item) => ({ state: item.state, id: item.id })
    ),
    rental: {
      rental_price: rental.rental_price,
      tenancy_deposit_insurance: rental.tenancy_deposit_insurance,
    },
  };
};

export default updatePropertyFilter;
