import { Route, RouteComponentProps, Switch } from "react-router-dom";
import { listingActions, listingInitialState } from "./constants";
import Edit from "./Edit";
import List, { ListingAction } from "./List";
import React, { useReducer } from "react";

export const listingReducer = (state, action: ListingAction) => {
  switch (action.type) {
    case listingActions.SET_CURRENT_PAGE: {
      return { ...state, currentPage: action.value as number };
    }
    case listingActions.SET_SORT_FIELD: {
      return { ...state, sortField: action.value };
    }
    case listingActions.SET_SORT_ORDER: {
      return { ...state, sortOrder: action.value };
    }
    case listingActions.SET_SEARCH: {
      return { ...state, search: action.value };
    }
    case listingActions.SET_POSTCODE: {
      return { ...state, postcode: action.value };
    }
    case listingActions.SET_STATUS: {
      return { ...state, status: action.value };
    }
    case listingActions.SET_UPDATED_AT: {
      return { ...state, updated_at: action.value };
    }
    case listingActions.SET_ADMIN_NAME: {
      return { ...state, admin_name: action.value };
    }
    default:
      return state;
  }
};

export type AdminListingProps = RouteComponentProps<{}> & {};
const AdminHome: React.FC<AdminListingProps> = ({ match }) => {
  const [state, dispatch] = useReducer(listingReducer, listingInitialState);
  const dispatchTo = (values: ListingAction[]) => {
    values.forEach(({ type, value }) => dispatch({ type, value }));
  };

  return (
    <div>
      <Switch>
        <Route
          exact
          path={`${match.path}`}
          render={(props) => (
            <List dispatch={dispatchTo} props={props} state={state} />
          )}
        />
        <Route component={Edit} exact path={`${match.path}/:id/edit`} />
        {/* Order does matter. Matching goes from top to down, more specific routes must go first*/}

        {/* <Route component={Edit} exact path={`${match.path}/:id/edit`} />
        <Route component={View} exact path={`${match.path}/:id`} /> */}
      </Switch>
    </div>
  );
};

export default AdminHome;
