import { Field, useForm } from "react-final-form";
import { GetProperty_admin_Property } from "../graphql/queries/__generated__/GetProperty";
import { InputField } from "../../../ui/molecules/InputField";
import { OnChange } from "react-final-form-listeners";
import { PropertyBody, PropertyContent } from "../../../ui/atoms/Property";
import { UserFormItem, UserFormRowFlex } from "../../../ui/atoms/UserForm";
import {
  composeValidators,
  required,
  validUkPostcode,
} from "../../../util/validations";
import PropertyVerification from "../PropertyVerification";
import React from "react";
import VerifyContext from "../PropertyEditContext";

type Props = {
  property: GetProperty_admin_Property;
};

const Address = (props: Props) => {
  const form = useForm();

  return (
    <VerifyContext.Consumer>
      {({ addressVerified, submitting }) => (
        <PropertyBody>
          {[
            "location.address1",
            "location.building",
            "location.flat",
            "location.street",
            "location.city",
            "location.county",
            "location.country",
            "location.postcode",
            "location.gps.latitude",
            "location.gps.longitude",
          ].map((k) => (
            <OnChange key={k} name={k}>
              {() => {
                if (form?.getState()?.values?.admin_verify?.address?.verified) {
                  form.change("admin_verify.address.verified", false);
                }
              }}
            </OnChange>
          ))}
          <PropertyContent>
            <UserFormRowFlex>
              <UserFormItem>
                <label htmlFor="location.address1">Address line</label>
                <Field
                  component={InputField}
                  name="location.address1"
                  readOnly={submitting}
                  validate={required("'Address line' is required field")}
                />
              </UserFormItem>
              <UserFormItem>
                <label htmlFor="location.building">Building/House name</label>
                <Field
                  component={InputField}
                  name="location.building"
                  readOnly={submitting}
                  style={{ textTransform: "uppercase" }}
                  validate={required("'Building' is required field")}
                />
              </UserFormItem>
              <UserFormItem>
                <label htmlFor="location.flat">Flat</label>
                <Field
                  component={InputField}
                  name="location.flat"
                  readOnly={submitting}
                  style={{ textTransform: "uppercase" }}
                />
              </UserFormItem>
            </UserFormRowFlex>

            <UserFormRowFlex>
              <UserFormItem>
                <label htmlFor="location.street">Street</label>
                <Field
                  component={InputField}
                  name="location.street"
                  readOnly={submitting}
                  validate={required("'Street' is required field")}
                />
              </UserFormItem>
            </UserFormRowFlex>

            <UserFormRowFlex>
              <UserFormItem>
                <label htmlFor="location.city">Town/City</label>
                <Field
                  component={InputField}
                  name="location.city"
                  readOnly={submitting}
                  validate={required("'Town/City' is required field")}
                />
              </UserFormItem>

              <UserFormItem>
                <label htmlFor="location.county">County</label>
                <Field
                  component={InputField}
                  name="location.county"
                  readOnly={submitting}
                  validate={required("'County' is required field")}
                />
              </UserFormItem>

              <UserFormItem>
                <label htmlFor="location.country">Country</label>
                <Field
                  component={InputField}
                  name="location.country"
                  readOnly={submitting}
                  validate={required("'Country' is required field")}
                />
              </UserFormItem>
            </UserFormRowFlex>

            <UserFormRowFlex>
              <UserFormItem>
                <label htmlFor="location.postcode">Post Code</label>
                <Field
                  component={InputField}
                  name="location.postcode"
                  readOnly={submitting}
                  style={{ textTransform: "uppercase" }}
                  validate={composeValidators(
                    required("'Postcode' is required field"),
                    validUkPostcode()
                  )}
                />
              </UserFormItem>
              <UserFormItem>
                <label htmlFor="location.gps.latitude">Latitude</label>
                <Field
                  component={InputField}
                  name="location.gps.latitude"
                  readOnly={submitting}
                  style={{ textTransform: "uppercase" }}
                  validate={required("'Latitude' is required field")}
                />
              </UserFormItem>
              <UserFormItem>
                <label htmlFor="location.gps.longitude">Longitude</label>
                <Field
                  component={InputField}
                  name="location.gps.longitude"
                  readOnly={submitting}
                  style={{ textTransform: "uppercase" }}
                  validate={required("'Longitude' is required field")}
                />
              </UserFormItem>
            </UserFormRowFlex>
          </PropertyContent>

          <PropertyVerification
            adminVerify={props.property.admin_verify}
            isVerified={!!addressVerified}
            property={props.property}
            showVerifiedButtons
            verifiedLabel="Verified"
            verifiedName="admin_verify.address.verified"
            verifyKey="address"
          />
        </PropertyBody>
      )}
    </VerifyContext.Consumer>
  );
};

export default Address;
