import {
  GetAllDocuments,
  GetAllDocumentsVariables,
} from "../graphql/queries/__generated__/GetAllDocuments";
import { GetProperty_admin_Property } from "../graphql/queries/__generated__/GetProperty";
import { PropertyBody, PropertyContent } from "../../../ui/atoms/Property";
import { Table, Tbody, ThInner, Thead, Tr } from "../../../ui/atoms/Table";
import { useQuery } from "@apollo/react-hooks";
import DocumentsRow from "../DocumentsRow";
import FormDocumentAdd from "../FormDocumentAdd/FormDocumentAdd";
import GET_DOCUMENTS from "../graphql/queries/GetAllDocuments.graphql";
import Pagebar from "../../../ui/molecules/Pagebar";
import Pagination from "../../../ui/molecules/Pagination";
import PropertyVerification from "../PropertyVerification";
import React, { useMemo } from "react";
import Spinner from "../../../ui/atoms/Spinner";
import SystemError from "../../../ui/atoms/SystemError";
import VerifyContext from "../PropertyEditContext";

const PER_PAGE = 10;

type Props = {
  property: GetProperty_admin_Property;
};

const Documents = ({ property }: Props) => {
  const { data, loading, error } = useQuery<
    GetAllDocuments,
    GetAllDocumentsVariables
  >(GET_DOCUMENTS, {
    variables: {
      property: property.id,
      removed: true,
      pagination: {
        page: 0,
        per_page: 100,
      },
    },
  });

  const documents = useMemo(() => data?.admin?.allDocuments?.documents ?? [], [
    data,
  ]);

  return (
    <VerifyContext.Consumer>
      {({ documentsVerified, submitting }) => (
        <PropertyBody>
          <PropertyContent>
            {error && <SystemError error={error} />}

            <Pagination perPage={PER_PAGE}>
              {({ page, setPage }) => {
                const range = (page - 1) * PER_PAGE;
                const documentsPage = documents.slice(range, range + PER_PAGE);

                return (
                  <>
                    {loading ? (
                      <Spinner />
                    ) : documents.length > 0 ? (
                      <>
                        <Table>
                          <Thead>
                            <Tr>
                              <ThInner>File</ThInner>
                              <ThInner>Type</ThInner>
                              <ThInner>Description</ThInner>
                              <ThInner>Expiry date</ThInner>
                              <ThInner>State</ThInner>
                              <ThInner />
                              <ThInner />
                            </Tr>
                          </Thead>
                          <Tbody>
                            {documentsPage.map((doc, index) => (
                              <DocumentsRow
                                key={doc.id}
                                document={doc}
                                index={index}
                                landlordId={property.people.landlord?.id!}
                                propertyId={property.id!}
                              />
                            ))}
                          </Tbody>
                        </Table>

                        <Pagebar
                          changePage={setPage}
                          curPage={page}
                          showNPages={3}
                          total={Math.ceil(documents.length / PER_PAGE)}
                        />
                      </>
                    ) : (
                      <h3>Documents not found</h3>
                    )}
                  </>
                );
              }}
            </Pagination>
          </PropertyContent>

          <PropertyVerification
            adminVerify={property.admin_verify}
            isVerified={!!documentsVerified}
            property={property}
            verifiedLabel="Verified"
            verifiedName="admin_verify.documents.verified"
            verifyKey="documents"
          >
            <>
              <FormDocumentAdd
                disabled={submitting}
                landlordId={property.people.landlord?.id!}
                propertyId={property.id as string}
              />
            </>
          </PropertyVerification>
        </PropertyBody>
      )}
    </VerifyContext.Consumer>
  );
};

export default Documents;
