import { DeleteButton } from "../../../ui/atoms/Button";
import { GetProperty_admin_Property } from "../graphql/queries/__generated__/GetProperty";
import { Link } from "react-router-dom";
import { ModalConfirm } from "../../../ui/molecules/Modal";
import { PropertyBody, PropertyContent } from "../../../ui/atoms/Property";
import {
  StatusDanger,
  StatusSuccess,
  UserAvatarSmall,
  UserInformSmall,
  UserItem,
  UserItemNameSmall,
  UserItemValue,
} from "../../../ui/atoms/UserCard";
import {
  TableCaption,
  TableResponse,
  Tbody,
  TdInner,
  TdInnerWidth1,
  ThInner,
  Thead,
  Tr,
  TrInner,
} from "../../../ui/atoms/Table";
import { format } from "date-fns";
import { useMutation } from "react-apollo";
import CANCEL_INVITATION from "../graphql/mutations/CancelInvitation.graphql";
import React, { useCallback, useState } from "react";
import Viewings from "../Viewings/Viewings";

type Props = {
  property: GetProperty_admin_Property;
};

const ViewingManager = (props: Props) => {
  const [isConfirmVisible, setConfirmVisibility] = useState<boolean>(false);
  const {
    people: { landlord, manager, manager_invitation },
    viewings,
  } = props.property;

  const [cancel] = useMutation(CANCEL_INVITATION, {
    refetchQueries: ["GetProperty"],
  });

  const handleCancelInvitation = useCallback(async () => {
    await cancel({ variables: { id: manager_invitation?.invitation_id } });
    setConfirmVisibility(false);
  }, [cancel, manager_invitation]);

  return (
    <>
      {isConfirmVisible && (
        <ModalConfirm
          onCancel={() => setConfirmVisibility(false)}
          onConfirm={handleCancelInvitation}
        >
          <span>
            If you cancel invite it makes the Landlord the viewing manager.
            <br />
            <br />
            Are you want to continue?
          </span>
        </ModalConfirm>
      )}

      <PropertyBody>
        <PropertyContent>
          {landlord?.id && (
            <UserInformSmall>
              <UserAvatarSmall
                alt=""
                src={
                  landlord.details?.avatar?.id
                    ? `/media/${landlord?.details?.avatar?.id}`
                    : "https://placekitten.com/80/80"
                }
              />
              <UserItem>
                <UserItemNameSmall>
                  Landlord of this property &mdash;&nbsp;
                  <Link
                    className="link"
                    to={
                      landlord?.admin
                        ? `/admin/${landlord?.id}/edit`
                        : `/users/${landlord?.id}/view`
                    }
                  >
                    {landlord?.details?.first_name || ""}{" "}
                    {landlord?.details?.last_name || ""}
                  </Link>
                </UserItemNameSmall>
                {landlord?.id === manager?.id ? (
                  <UserItemValue>
                    <StatusSuccess>
                      Landlord is managing viewings themselves
                    </StatusSuccess>
                  </UserItemValue>
                ) : null}
                {!manager?.id ? (
                  <UserItemValue>
                    <StatusDanger>
                      This property haven't got manager
                    </StatusDanger>
                  </UserItemValue>
                ) : null}
              </UserItem>
            </UserInformSmall>
          )}
          {manager?.id && landlord?.id !== manager?.id && (
            <UserInformSmall>
              <UserAvatarSmall
                alt=""
                src={
                  manager?.details?.avatar?.id
                    ? `/media/${manager?.details?.avatar?.id}`
                    : "https://placekitten.com/60/60"
                }
              />
              <UserItem>
                <UserItemNameSmall>
                  Manager of this property &mdash;&nbsp;
                  <Link
                    className="link"
                    to={
                      manager!.admin
                        ? `/admin/${manager?.id}/edit`
                        : `/users/${manager?.id}/view`
                    }
                  >
                    {manager?.details?.first_name || ""}{" "}
                    {manager?.details?.last_name || ""}
                  </Link>
                </UserItemNameSmall>
              </UserItem>
            </UserInformSmall>
          )}
          {manager_invitation && manager_invitation.pending && (
            <TableResponse>
              <TableCaption>
                Landlord has invited tenant to do viewings
              </TableCaption>
              <Thead>
                <Tr>
                  <ThInner>Email</ThInner>
                  <ThInner>Status</ThInner>
                  <ThInner>Invite&nbsp;ID</ThInner>
                  <ThInner>Date</ThInner>
                  <ThInner>Action</ThInner>
                </Tr>
              </Thead>
              <Tbody>
                <TrInner>
                  <TdInner>{manager_invitation.invitee_email}</TdInner>
                  <TdInner>
                    <b>
                      <StatusSuccess>Active</StatusSuccess>
                    </b>
                  </TdInner>
                  <TdInner>{manager_invitation.workflow}</TdInner>
                  <TdInner>
                    <b>
                      {manager_invitation.sent
                        ? format(
                            new Date(manager_invitation.sent),
                            "dd MMM yyyy, HH:mm:ss"
                          )
                        : "- - -"}
                    </b>
                  </TdInner>
                  <TdInnerWidth1>
                    <DeleteButton onClick={() => setConfirmVisibility(true)}>
                      Cancel&nbsp;invite
                    </DeleteButton>
                  </TdInnerWidth1>
                </TrInner>
              </Tbody>
            </TableResponse>
          )}
          {/* {!manager.id && !pending && (
            <>
              <Gap50 />
              in progress TODO after BE ready
              <UserCardActionButtons>
                <PrimaryButton>
                  Make the Landlord the viewing manager
                </PrimaryButton>
                <SuccessButton>Send new invite</SuccessButton>
              </UserCardActionButtons>
            </>
          )} */}

          {viewings ? <Viewings viewings={viewings} /> : null}
        </PropertyContent>
      </PropertyBody>
    </>
  );
};

export default ViewingManager;
