import * as P from "../../ui/atoms/Payment";
import { GetAllMaintenances_admin_allMaintenances_data } from "./graphql/queries/__generated__/GetAllMaintenances";
import {
  GetLandlord,
  GetLandlordVariables,
} from "./graphql/queries/__generated__/GetLandlord";
import {
  GetLocationProperty,
  GetLocationPropertyVariables,
} from "./graphql/queries/__generated__/GetLocationProperty";
import { Link } from "react-router-dom";
import { ModalWide } from "../../ui/molecules/Modal";
import { Td, Tr } from "../../ui/atoms/Table";
import { css } from "@emotion/core";
import { formatDateTime } from "../../util/date";
import { humanizeEnum } from "../../util/enums_converter";
import { maintenance_api_MaintenanceStatusEnum } from "../../globalTypes";
import { useLazyQuery, useQuery } from "@apollo/react-hooks";
import Collapse from "../../ui/molecules/Collapse";
import GET_PROPERTY_LOCATION from "./graphql/queries/GetLocation.graphql";
import GET_USER from "./graphql/queries/GetUser.graphql";
import NoBR from "../../ui/atoms/NoBR";
import React, { useState } from "react";
import Spinner from "../../ui/atoms/Spinner";
import format from "date-fns/format";
import styled from "@emotion/styled";
import theme from "../../ui/theme";

export type ListItemProps = {
  data: GetAllMaintenances_admin_allMaintenances_data;
};

const ListItem: React.FC<ListItemProps> = ({ data }) => {
  const [isDetailsVisible, setDetailsVisibility] = useState(false);
  const openDetails = () => setDetailsVisibility(true);
  const closeDetails = () => setDetailsVisibility(false);

  const { specialist } = data;

  const locationData = useQuery<
    GetLocationProperty,
    GetLocationPropertyVariables
  >(GET_PROPERTY_LOCATION, {
    variables: {
      id: data.property,
    },
    skip: !data.property,
  });
  const location = locationData.data?.admin?.Property?.location;

  const landlordData = useQuery<GetLandlord, GetLandlordVariables>(GET_USER, {
    variables: {
      id: data.landlord,
    },
    skip: !data.landlord,
  });
  const landlord = landlordData?.data?.admin?.User;

  const [getUserData, userData] = useLazyQuery<
    GetLandlord,
    GetLandlordVariables
  >(GET_USER, {
    variables: {
      id: data.user,
    },
  });
  const userRaisedBy = userData?.data?.admin?.User;

  return (
    <>
      <Tr>
        <Td colSpan={3}>
          {locationData.loading ? (
            <Loader>
              <Spinner />
            </Loader>
          ) : location ? (
            <>
              {[
                location.address1,
                location.address2,
                location.address3,
                location.address4,
              ]
                .filter(Boolean)
                .join(", ")}
              {location.city && (
                <div>
                  <b>{location.city}</b>
                </div>
              )}
              {location.postcode && (
                <div>
                  <b>{location.postcode}</b>
                </div>
              )}
            </>
          ) : null}
        </Td>
        <Td colSpan={2}>
          <NoBR>
            {data.created_at
              ? format(new Date(data.created_at), "dd MMM yyyy")
              : "- - -"}
          </NoBR>
          <NoBR>
            {data.created_at
              ? format(new Date(data.created_at), "HH:mm:ss")
              : "- - -"}
          </NoBR>
        </Td>
        <Td colSpan={2}>
          {landlordData.loading ? (
            <Loader>
              <Spinner />
            </Loader>
          ) : landlordData.data ? (
            <>
              <Link className="link" to={`/users/${landlord?.id}/view`}>
                {[landlord?.details?.first_name, landlord?.details?.last_name]
                  .filter(Boolean)
                  .join(" ")}
              </Link>
            </>
          ) : (
            "N/A"
          )}
        </Td>
        <Td colSpan={2}>
          {data.place ? humanizeEnum(data.place).label : "N/A"}
        </Td>
        <Td colSpan={2}>
          <span
            className={
              data.status === maintenance_api_MaintenanceStatusEnum.IN_WORKS
                ? "text-warning bold"
                : data.status ===
                  maintenance_api_MaintenanceStatusEnum.NOT_ADDRESSED
                ? "text-danger bold"
                : data.status === maintenance_api_MaintenanceStatusEnum.REPAIRED
                ? "text-success bold"
                : ""
            }
          >
            {data.status ? humanizeEnum(data.status).label : "N/A"}
          </span>
        </Td>
        <Td>
          <span
            className="link"
            onClick={() => {
              getUserData();
              openDetails();
            }}
            role="presentation"
          >
            View
          </span>
        </Td>
      </Tr>
      {isDetailsVisible ? (
        <ModalWide onCancel={closeDetails} title={`Maintenance Details`}>
          <Collapse opened>
            {({ toggle, isOpened }) => (
              <Payment status={data.status}>
                <P.PaymentHead>
                  <P.PaymentDescription>
                    <span
                      className={
                        data.status ===
                        maintenance_api_MaintenanceStatusEnum.IN_WORKS
                          ? "text-warning bold"
                          : data.status ===
                            maintenance_api_MaintenanceStatusEnum.NOT_ADDRESSED
                          ? "text-danger bold"
                          : data.status ===
                            maintenance_api_MaintenanceStatusEnum.REPAIRED
                          ? "text-success bold"
                          : ""
                      }
                    >
                      {data.status ? humanizeEnum(data.status).label : "N/A"}
                    </span>
                  </P.PaymentDescription>
                  {data.status ===
                  maintenance_api_MaintenanceStatusEnum.NOT_ADDRESSED ? (
                    <P.StatusError />
                  ) : data.status ===
                    maintenance_api_MaintenanceStatusEnum.IN_WORKS ? (
                    <P.StatusSubmitted />
                  ) : data.status ===
                    maintenance_api_MaintenanceStatusEnum.REPAIRED ? (
                    <P.StatusConfirmed />
                  ) : null}
                </P.PaymentHead>
                {isOpened && (
                  <P.PaymentBody>
                    <P.ColumnWide>
                      <P.ColumnTitle>Property address</P.ColumnTitle>
                      <P.ColumnValue>
                        <a
                          className="link"
                          href={`/#/listing/${data.property}/edit`}
                          rel="noopener noreferrer"
                          target="_blank"
                        >
                          {locationData.loading ? (
                            <Loader>
                              <Spinner />
                            </Loader>
                          ) : location ? (
                            <>
                              {[
                                location.address1,
                                location.address2,
                                location.address3,
                                location.address4,
                              ]
                                .filter(Boolean)
                                .join(", ")}
                              {location.city ||
                              location.postcode ||
                              location.country ? (
                                <div>
                                  {[
                                    location.city,
                                    location.postcode,
                                    location.country,
                                  ]
                                    .filter(Boolean)
                                    .join(", ")}
                                </div>
                              ) : null}
                            </>
                          ) : null}
                        </a>
                      </P.ColumnValue>
                    </P.ColumnWide>
                    <P.ColumnNarrow>
                      <P.ColumnTitle>Landlord name</P.ColumnTitle>
                      <P.ColumnValue>
                        {landlord ? (
                          <>
                            <a
                              className="link"
                              href={`/#/users/${landlord?.id}/view`}
                              rel="noopener noreferrer"
                              target="_blank"
                            >
                              {[
                                landlord.details?.first_name,
                                landlord.details?.last_name,
                              ]
                                .filter(Boolean)
                                .join(" ")}
                            </a>
                          </>
                        ) : (
                          "N/A"
                        )}
                      </P.ColumnValue>
                    </P.ColumnNarrow>

                    <P.ColumnWide>
                      <P.ColumnTitle>Raised by</P.ColumnTitle>
                      <P.ColumnValue>
                        {userRaisedBy ? (
                          <>
                            <a
                              className="link"
                              href={`/#/users/${userRaisedBy.id}/view`}
                              rel="noopener noreferrer"
                              target="_blank"
                            >
                              {[
                                userRaisedBy.details?.first_name,
                                userRaisedBy.details?.last_name,
                              ]
                                .filter(Boolean)
                                .join(" ")}
                            </a>
                          </>
                        ) : (
                          "N/A"
                        )}
                      </P.ColumnValue>
                    </P.ColumnWide>
                    {specialist.local_heroes ? (
                      <P.ColumnNarrow>
                        <P.ColumnTitle>Assignee (local heroes)</P.ColumnTitle>
                        <P.ColumnValue>
                          <div>
                            Start:{" "}
                            {formatDateTime(
                              specialist.local_heroes.time_slot_start
                            )}
                          </div>
                          <div>
                            End:{" "}
                            {formatDateTime(
                              specialist.local_heroes.time_slot_end
                            )}
                          </div>
                        </P.ColumnValue>
                      </P.ColumnNarrow>
                    ) : specialist.someone_else ? (
                      <P.ColumnNarrow>
                        <P.ColumnTitle>Assignee (someone else)</P.ColumnTitle>
                        <P.ColumnValue>
                          {specialist.someone_else.name}
                          <div>{specialist.someone_else.phone_number}</div>
                          <div>
                            Visit at:{" "}
                            {formatDateTime(specialist.someone_else.visit_at)}
                          </div>
                        </P.ColumnValue>
                      </P.ColumnNarrow>
                    ) : (
                      <P.ColumnNarrow>
                        <P.ColumnTitle>Assignee</P.ColumnTitle>
                        <P.ColumnValue>- - -</P.ColumnValue>
                      </P.ColumnNarrow>
                    )}

                    <P.ColumnWide>
                      <P.ColumnTitle>What is the issue?</P.ColumnTitle>
                      <P.ColumnValue>
                        {data.title ? data.title : null}
                        {data.description ? (
                          <div>{data.description}</div>
                        ) : null}
                      </P.ColumnValue>
                    </P.ColumnWide>
                    <P.ColumnNarrow>
                      <P.ColumnTitle>Date and time</P.ColumnTitle>
                      <P.ColumnValue>
                        {data.created_at
                          ? format(
                              new Date(data.created_at),
                              "dd MMM yyyy HH:mm"
                            )
                          : "N/A"}
                      </P.ColumnValue>
                    </P.ColumnNarrow>
                    <P.ColumnWide>
                      <P.ColumnTitle>Description</P.ColumnTitle>
                      <P.ColumnValue>{data.description}</P.ColumnValue>
                    </P.ColumnWide>
                    <P.ColumnWide>
                      <P.ColumnTitle>Location</P.ColumnTitle>
                      <P.ColumnValue>
                        {data.place ? humanizeEnum(data.place).label : "N/A"}
                      </P.ColumnValue>
                    </P.ColumnWide>
                    <P.ImagesGroup>
                      {(data.files ?? []).map((doc) => (
                        <P.ImageAnchor
                          key={doc.id}
                          href={`/media/${doc.id}`}
                          target="_blank"
                        >
                          <P.Image src={`/media/${doc.id}`} />
                          <P.Image src={`/media/${doc?.id}`} />
                        </P.ImageAnchor>
                      ))}
                    </P.ImagesGroup>
                  </P.PaymentBody>
                )}
              </Payment>
            )}
          </Collapse>
        </ModalWide>
      ) : null}
    </>
  );
};

const Payment = styled(P.Payment)<{
  status: maintenance_api_MaintenanceStatusEnum | null;
}>`
  ${({ status }) =>
    status === maintenance_api_MaintenanceStatusEnum.IN_WORKS
      ? css`
          border: solid 1px ${theme.colors.border.waiting};
        `
      : status === maintenance_api_MaintenanceStatusEnum.NOT_ADDRESSED
      ? css`
          border: solid 1px ${theme.colors.border.error};
        `
      : status === maintenance_api_MaintenanceStatusEnum.REPAIRED
      ? css`
          border: solid 1px ${theme.colors.border.success};
        `
      : css`
          border: solid 1px ${theme.colors.border.default};
        `}
`;

const Loader = styled.div`
  width: 16px;
  height: 16px;
  display: flex;
  align-items: center;
  justify-content: center;
`;

export default ListItem;
