import { ModalConfirm } from "../../../../../ui/molecules/Modal";
import { mortgage_api_MortgageLeadStageEnum } from "../../../../../globalTypes";
import DealItem from "../DealItem";
import Notes from "../Notes";
import React, { useState } from "react";
import StageProgress from "../StageProgress";
import classNames from "classnames";
import css from "./index.module.css";

const cn = classNames.bind(css);

const DealCard = () => {
  const [isOpen, setIsOpen] = useState(true);
  const [stage, setStage] = useState(mortgage_api_MortgageLeadStageEnum.AIP);
  const [newStage, setNewStage] = useState(stage);

  const [isConfirmModalOpen, setIsConfirmModalOpen] = useState(false);
  const handleOpenClick = () => {
    setIsOpen((prevState) => !prevState);
  };
  const handleStageChange = (value: mortgage_api_MortgageLeadStageEnum) => {
    setIsConfirmModalOpen(true);
    setNewStage(value);
  };

  const handleConfirm = () => {
    setStage(newStage);
    setIsConfirmModalOpen(false);
  };

  return (
    <>
      <div className={cn(css.container)}>
        <div className={css.head} onClick={handleOpenClick} role="presentation">
          <div className={cn(css.icon, { [css.iconOpen]: isOpen })}>
            <i className="material-icons">expand_more</i>
          </div>

          <span className={css.title}> Deal 1 </span>
        </div>

        {isOpen && (
          <div className={css.dealContainer}>
            <div className={css.infoWrapper}>
              <div className={css.info}>
                <span className={css.infoHeader}>Assigned to</span>
                <span>Alex</span>
              </div>
              <div className={css.info}>
                <span className={css.infoHeader}>Deal value</span>
                <span> 30 000$</span>
              </div>
              <div className={css.info}>
                <span className={css.infoHeader}>Renewal date</span>
                <span>25.04.2021</span>
              </div>
            </div>
            <div className={css.infoWrapper}>
              <StageProgress onStageChange={handleStageChange} stage={stage} />
            </div>
            <DealItem title={"Qualification Data"}>
              <Notes />
            </DealItem>
            <DealItem title={"Sourcing Results"}>
              <Notes />
            </DealItem>
            <DealItem title={"Note"}>
              <Notes />
            </DealItem>
          </div>
        )}
      </div>
      {isConfirmModalOpen && (
        <ModalConfirm
          onCancel={() => {
            setIsConfirmModalOpen(false);
          }}
          onConfirm={handleConfirm}
        >
          <span className={css.confirmText}>Change stage?</span>
        </ModalConfirm>
      )}
    </>
  );
};

export default DealCard;
