import { Field, Form } from "react-final-form";
import {
  InputField,
  InputFieldTouched,
} from "../../../../../ui/molecules/InputField";
import { LeadStageOptions } from "../../constants";
import { PrimaryButton, SecondaryButton } from "../../../../../ui/atoms/Button";
import { TextareaFieldTouched } from "../../../../../ui/molecules/TextareaField";
import { required } from "../../../../../util/validations";
import {
  saveMortgageLead,
  saveMortgageLeadVariables,
} from "../../../graphql/mutations/__generated__/saveMortgageLead";
import { useMutation } from "react-apollo";
import Dropdown from "../../../../../ui/molecules/Dropdown";
import React from "react";
import SAVE_LEAD from "../../../graphql/mutations/SaveMortgageLead.graphql";
import css from "./index.module.css";

type Props = {
  onClose: () => void;
};

const initialValues = {
  lead: {
    stage: LeadStageOptions[0],
  },
};

const AddLead = ({ onClose }: Props) => {
  const [saveLead, { loading, error }] = useMutation<
    saveMortgageLead,
    saveMortgageLeadVariables
  >(SAVE_LEAD);

  const handleSubmit = async ({ lead }) => {
    const data = await saveLead({
      variables: {
        ...lead,
        stage: lead.stage.value,
        schedule_date: new Date(lead.schedule_date).toUTCString(),
      },
    });

    if (!data?.errors) {
      onClose();
    }
  };
  return (
    <Form
      initialValues={initialValues}
      onSubmit={handleSubmit}
      render={({ handleSubmit }) => {
        return (
          <form onSubmit={handleSubmit}>
            <div className={css.formRow}>
              <div className={css.inputGroup}>
                <label htmlFor="lead.name">Full name</label>
                <Field
                  component={InputField}
                  name={"lead.name"}
                  validate={required("Name is require field")}
                />
              </div>
              <div className={css.inputGroup}>
                <label htmlFor="lead.name">Email</label>
                <Field
                  component={InputField}
                  name={"lead.email"}
                  validate={required("Email is require field")}
                />
              </div>
            </div>
            <div className={css.formRow}>
              <div className={css.inputGroup}>
                <label htmlFor="lead.assigned_to">Assigned to</label>
                <Field
                  component={InputField}
                  name="lead.assigned_to"
                  validate={required("Assigned to is require field")}
                />
              </div>
              <div className={css.inputGroup}>
                <label htmlFor="lead.stage">Stage</label>
                <Field
                  name="lead.stage"
                  render={({ input }) => (
                    <Dropdown input={input} options={LeadStageOptions} />
                  )}
                />
              </div>
            </div>
            <div className={css.formRow}>
              <div className={css.inputGroup}>
                <label htmlFor="lead.user_id">User id</label>
                <Field component={InputField} name="lead.user_id" />
              </div>
            </div>
            <div className={css.formRow}>
              <div className={css.inputGroup}>
                <label htmlFor="lead.note">Note</label>
                <Field
                  component={TextareaFieldTouched}
                  name="lead.note"
                  rows={3}
                />
              </div>
            </div>
            <div className={css.formRow}>
              <div className={css.inputGroup}>
                <label htmlFor="lead.schedule_date">Schedule date</label>
                <Field
                  component={InputFieldTouched}
                  name="lead.schedule_date"
                  type="date"
                />
              </div>
              <div className={css.inputGroup}>
                <label htmlFor="lead.phone">Phone</label>
                <Field component={InputField} name="lead.phone" />
              </div>
            </div>
            <div className={css.buttonWrapper}>
              <PrimaryButton disabled={loading} type="submit">
                Save
              </PrimaryButton>
              <SecondaryButton onClick={onClose} type="button">
                Cancel
              </SecondaryButton>
              {error && <span>{error.message}</span>}
            </div>
          </form>
        );
      }}
    />
  );
};

export default AddLead;
