import {
  ButtonsGroup,
  UserFormAction,
  UserFormOverlay,
  UserFormRow,
} from "../../ui/atoms/UserForm";
import {
  CategoryOptions,
  ChannelOptions,
  TargetRoleOptions,
  isElement,
} from "./constants";
import { CheckboxBlock } from "../../ui/atoms/CheckboxInput";
import { Field, Form } from "react-final-form";
import { FormData } from "./types";
import { InputField } from "../../ui/molecules/InputField";
import { Notification_Api_EventChannelEnum } from "../../graphql-schema-types.generated";
import { PrimaryButton, SecondaryButton } from "../../ui/atoms/Button";
import { TextareaFieldTouched } from "../../ui/molecules/TextareaField";
import Dropdown from "../../ui/molecules/Dropdown";
import React, { useCallback } from "react";

type Props = {
  currentNotificationData: FormData;
  onClose: () => void;
  onSubmit: ({ notification: FormDataNotification }) => void;
};
const EditForm = ({ currentNotificationData, onClose, onSubmit }: Props) => {
  const handleSubmit = useCallback(
    ({ notification }) => onSubmit({ notification }),
    [onSubmit]
  );

  return (
    <Form
      initialValues={currentNotificationData}
      onSubmit={handleSubmit}
      render={({ handleSubmit, submitting, valid }) => (
        <form onSubmit={handleSubmit}>
          {submitting && <UserFormOverlay />}

          <div className="formRow">
            <div className="inputGroup">
              <label htmlFor="notification.channel">Channel</label>
              <Field
                name="notification.channel"
                render={({ input }) => (
                  <Dropdown input={input} options={ChannelOptions} />
                )}
              />
            </div>
          </div>
          <div className="formRow">
            <div className="inputGroup">
              <label htmlFor="notification.target">User</label>
              <Field
                name="notification.target"
                render={({ input }) => (
                  <Dropdown input={input} options={TargetRoleOptions} />
                )}
              />
            </div>
          </div>
          <div className="formRow">
            <div className="inputGroup">
              <label htmlFor="notification.category">Category</label>
              <Field
                name="notification.category"
                render={({ input }) => (
                  <Dropdown input={input} options={CategoryOptions} />
                )}
              />
            </div>
          </div>
          <UserFormRow>
            <label htmlFor="notification.template">Template</label>
            <Field
              component={TextareaFieldTouched}
              name="notification.template"
              rows={5}
            />
          </UserFormRow>
          {isElement(
            currentNotificationData.notification.channel,
            Notification_Api_EventChannelEnum.EventChannelEmail
          ) && (
            <UserFormRow>
              <label htmlFor="notification.data.sendgridID">
                Sendgrid Template
              </label>
              <Field
                component={InputField}
                name="notification.data.sendgridID"
              />
            </UserFormRow>
          )}
          {isElement(
            currentNotificationData.notification.channel,
            Notification_Api_EventChannelEnum.EventChannelPlatform
          ) && (
            <UserFormRow>
              <label htmlFor="notification.data.associatedURI">
                Clicked Link
              </label>
              <Field
                component={InputField}
                defaultValue="/dashboard/[propertyId]/overview"
                name="notification.data.associatedURI"
              />
            </UserFormRow>
          )}
          <UserFormRow>
            <Field
              name="notification.disabled"
              render={({ input }) => (
                <CheckboxBlock>
                  <input type="checkbox" {...input} />
                  <span>Disabled</span>
                </CheckboxBlock>
              )}
              type="checkbox"
            />
          </UserFormRow>
          <UserFormAction>
            <ButtonsGroup>
              <SecondaryButton onClick={onClose} type="button">
                Cancel
              </SecondaryButton>
              <PrimaryButton disabled={submitting || !valid} type="submit">
                Save
              </PrimaryButton>
            </ButtonsGroup>
          </UserFormAction>
        </form>
      )}
    />
  );
};

export default EditForm;
