import { Notification } from "./types";
import {
  Notification_Api_CategoryEnum,
  Notification_Api_EventChannelEnum,
  Notification_Api_RoleEnum,
} from "../../graphql-schema-types.generated";
import { Td, Tr } from "../../ui/atoms/Table";
import { sentenceCase } from "change-case";
import React from "react";

const getNotificationChannel = (status: Notification_Api_EventChannelEnum) => {
  switch (status) {
    case Notification_Api_EventChannelEnum.EventChannelEmail:
      return "Email";
    case Notification_Api_EventChannelEnum.EventChannelPlatform:
      return "In-Platform";
    case Notification_Api_EventChannelEnum.EventChannelSlack:
      return "Slack";
    case Notification_Api_EventChannelEnum.EventChannelSms:
      return "SMS";
    case Notification_Api_EventChannelEnum.EventChannelWhatsapp:
      return "WhatsApp";
    default:
      return sentenceCase(status);
  }
};

const getNotificationRole = (status: Notification_Api_RoleEnum) => {
  switch (status) {
    case Notification_Api_RoleEnum.RoleAdmin:
      return "Admin";
    case Notification_Api_RoleEnum.RoleAuthor:
      return "Author";
    case Notification_Api_RoleEnum.RoleGuarantor:
      return "Guarantor";
    case Notification_Api_RoleEnum.RoleLandlord:
      return "Landlord";
    case Notification_Api_RoleEnum.RoleManager:
      return "Manager";
    case Notification_Api_RoleEnum.RoleTenant:
      return "Tenant";
    default:
      return sentenceCase(status);
  }
};

const getNotificationCategory = (status: Notification_Api_CategoryEnum) => {
  switch (status) {
    case Notification_Api_CategoryEnum.CategoryAccount:
      return "Account";
    case Notification_Api_CategoryEnum.CategoryComplianceProduct:
      return "Compliance Product";
    case Notification_Api_CategoryEnum.CategoryContracts:
      return "Contacts";
    case Notification_Api_CategoryEnum.CategoryDocument:
      return "Document";
    case Notification_Api_CategoryEnum.CategoryEndOfTenancy:
      return "End of Tenancy";
    case Notification_Api_CategoryEnum.CategoryHoldingDeposit:
      return "Holding Deposit";
    case Notification_Api_CategoryEnum.CategoryInsurances:
      return "Insurances";
    case Notification_Api_CategoryEnum.CategoryInvitation:
      return "Invitation";
    case Notification_Api_CategoryEnum.CategoryListing:
      return "Listing";
    case Notification_Api_CategoryEnum.CategoryMaintenance:
      return "Maintenance";
    case Notification_Api_CategoryEnum.CategoryOffer:
      return "Offer";
    case Notification_Api_CategoryEnum.CategoryPayment:
      return "Payment";
    case Notification_Api_CategoryEnum.CategoryReferencing:
      return "Referencing";
    case Notification_Api_CategoryEnum.CategoryRenewal:
      return "Renewal";
    case Notification_Api_CategoryEnum.CategoryViewing:
      return "Viewing";
    default:
      return sentenceCase(status);
  }
};

export type ListItemProps = {
  notification: Notification;
  onOpenDetailsClick: (notification: Notification) => void;
};

const ListItem: React.FC<ListItemProps> = ({ notification, onOpenDetailsClick }) => (
  <Tr key={notification.ID}>
    <Td>{getNotificationChannel(notification.channel)}</Td>
    <Td>{getNotificationRole(notification.target)}</Td>
    <Td>{getNotificationCategory(notification.category)}</Td>
    <Td>{notification.template}</Td>
    <Td>
      <span
        className="link"
        onClick={() => onOpenDetailsClick(notification)}
	role="button"
	tabIndex={0}
      >
        Edit
      </span>
    </Td>
  </Tr>
);

export default ListItem;
