import { GetOffer_admin_Offer } from "./graphql/queries/__generated__/GetOffer";
import { Link } from "react-router-dom";
import { OFFER_STAGE, RENT_PLAN_PACKAGES } from "./constants";
import {
  OfferCardItem,
  OfferCardItemTitle,
  OfferCardItemValue,
  OfferCardTitle,
  OfferGrid,
} from "../../ui/atoms/Offer";
import { offer_api_OfferStateEnum } from "../../globalTypes";
import AssignAdminModal from "../admin/AssignAdminModal";
import ClickableText from "../../ui/molecules/ClickableText";
import EmailLink from "../../ui/atoms/EmailLink";
import React, { FC, useState } from "react";
import UpdateRentPlanModal from "./UpdateRentPlanModal";
import strip_typenames from "../../util/strip_typenames";

type Props = {
  offer: GetOffer_admin_Offer;
};

const OfferCard: FC<Props> = ({ offer }) => {
  const [showAssignModal, setShowAssignModal] = useState(false);
  const [showRentPlanModal, setShowRentPlanModal] = useState(false);
  const {
    property: {
      id: propertyId,
      location,
      people: { landlord, manager },
    },
    landlord: ll,
  } = offer;
  const tenant = offer.tenants?.[0];
  const adminInfo = offer.administrator;

  return (
    <div>
      <OfferCardTitle>Offer ID: {offer.id}</OfferCardTitle>
      <OfferGrid>
        <OfferCardItem>
          <OfferCardItemTitle>Property</OfferCardItemTitle>
          <OfferCardItemValue>
            {Object.values(strip_typenames(location))
              .filter(Boolean)
              .join(", ")}
          </OfferCardItemValue>
          <OfferCardItemValue>
            <Link className="link" to={`/listing/${propertyId}/edit`}>
              {propertyId}
            </Link>
          </OfferCardItemValue>
        </OfferCardItem>

        <OfferCardItem>
          <OfferCardItemTitle>Current stage</OfferCardItemTitle>
          <OfferCardItemValue>{OFFER_STAGE[offer.state]}</OfferCardItemValue>
        </OfferCardItem>

        <OfferCardItem>
          <OfferCardItemTitle>Landlord</OfferCardItemTitle>
          <OfferCardItemValue>
            <Link className="link" to={`/users/${landlord?.id}/view`}>
              {landlord?.details?.first_name}
              &nbsp;
              {landlord?.details?.last_name}
            </Link>
          </OfferCardItemValue>

          {ll.email_primary && (
            <OfferCardItemValue>
              <EmailLink href={`mailto:${ll.email_primary}`}>
                {ll.email_primary}
              </EmailLink>
            </OfferCardItemValue>
          )}
        </OfferCardItem>

        <OfferCardItem>
          <OfferCardItemTitle>Current manager</OfferCardItemTitle>
          <OfferCardItemValue>
            {manager?.id ? (
              <Link className="link" to={`/users/${manager?.id}/view`}>
                {manager?.details?.first_name}
                &nbsp;
                {manager?.details?.last_name}
              </Link>
            ) : (
              "—"
            )}
          </OfferCardItemValue>

          {manager?.contact?.email_primary && (
            <OfferCardItemValue>
              <EmailLink href={`mailto:${manager?.contact?.email_primary}`}>
                {manager?.contact?.email_primary}
              </EmailLink>
            </OfferCardItemValue>
          )}
        </OfferCardItem>

        <OfferCardItem>
          <OfferCardItemTitle>Tenant</OfferCardItemTitle>
          {tenant && (
            <>
              <OfferCardItemValue>
                <Link className="link" to={`/users/${tenant.user}/view`}>
                  {tenant.first_name}
                  &nbsp;
                  {tenant.last_name}
                </Link>
              </OfferCardItemValue>

              {tenant.email_primary && (
                <OfferCardItemValue>
                  <EmailLink href={`mailto:${tenant.email_primary}`}>
                    {tenant.email_primary}
                  </EmailLink>
                </OfferCardItemValue>
              )}
            </>
          )}
        </OfferCardItem>
        <OfferCardItem>
          <OfferCardItemTitle>ASSIGNED TO</OfferCardItemTitle>
          <OfferCardItemValue>
            {adminInfo
              ? `${adminInfo?.details?.first_name} ${adminInfo?.details?.last_name}`
              : "N/A"}
            <ClickableText
              onClick={() => setShowAssignModal(true)}
              text="Reassign"
            />
          </OfferCardItemValue>
        </OfferCardItem>
        <OfferCardItem>
          <OfferCardItemTitle>Rent collection plan</OfferCardItemTitle>
          <OfferCardItemValue>
            {RENT_PLAN_PACKAGES[offer.rent_plan]}
            {(offer.state === offer_api_OfferStateEnum.SIGNED ||
              offer.state === offer_api_OfferStateEnum.RENTPAID) && (
              <ClickableText
                onClick={() => setShowRentPlanModal(true)}
                text="Change"
              />
            )}
          </OfferCardItemValue>
        </OfferCardItem>
        <OfferCardItem></OfferCardItem>
      </OfferGrid>

      {showAssignModal && (
        <AssignAdminModal
          offerId={offer.id}
          setModalVisibility={setShowAssignModal}
        />
      )}

      {showRentPlanModal && (
        <UpdateRentPlanModal
          offer={offer}
          setModalVisibility={setShowRentPlanModal}
        />
      )}
    </div>
  );
};

export default OfferCard;
