import { GetOffer_admin_Offer_invoices_payments_matches as Match } from "./graphql/queries/__generated__/GetOffer";
import {
  ReconciliationStatusFull,
  ReconciliationStatusPartial,
  ReconciliationStatusUnknown,
} from "../../ui/atoms/Status";
import { invoice_api_TransactionMatchEnum as TransactionMatchEnum } from "../../globalTypes";
import React from "react";

const PaymentReconciliationStatus = ({
  matches,
}: {
  readonly matches: ReadonlyArray<Match> | null;
}) => {
  const res: TransactionMatchEnum[] = (matches ?? [])
    .filter((m) => m.matched)
    .reduce(
      (a, m) => [...a, ...(m.matched as TransactionMatchEnum[])],
      [] as TransactionMatchEnum[]
    );

  if (
    res.includes(TransactionMatchEnum.TRANSACTION_MATCH_AMOUNT) &&
    res.includes(TransactionMatchEnum.TRANSACTION_MATCH_IVR)
  ) {
    return <ReconciliationStatusFull>Full match</ReconciliationStatusFull>;
  } else if (res.includes(TransactionMatchEnum.TRANSACTION_MATCH_AMOUNT)) {
    return (
      <ReconciliationStatusPartial>
        Partial match by Amount
      </ReconciliationStatusPartial>
    );
  } else if (res.includes(TransactionMatchEnum.TRANSACTION_MATCH_IVR)) {
    return (
      <ReconciliationStatusPartial>
        Partial match by IVR
      </ReconciliationStatusPartial>
    );
  }

  return <ReconciliationStatusUnknown>Unknown</ReconciliationStatusUnknown>;
};

export default PaymentReconciliationStatus;
