import { Link } from "react-router-dom";
import { formatDateWordTime } from "../../../../../util/date";
import { formatPrice } from "../../../../../util/price";
import { invoice_api_InvoiceStatusEnum } from "../../../../../globalTypes";
import { sentenceCase } from "change-case";
import React, { FC } from "react";
import styled from "@emotion/styled";

type Props = {
  invoice_id: string;
  status: invoice_api_InvoiceStatusEnum;
  reference: string;
  created_at: string;
  updated_at: string;
  amount: number;
};

const Invoice: FC<Props> = ({
  invoice_id,
  status,
  reference,
  created_at,
  updated_at,
  amount,
}) => {
  return (
    <DepositInfo>
      <DepositInfoRow>
        <DepositInfoTitle>Invoice status</DepositInfoTitle>
        <div>{sentenceCase(status)}</div>
      </DepositInfoRow>
      <DepositInfoRow>
        <DepositInfoTitle>Invoice ID</DepositInfoTitle>
        <div>
          {invoice_id} &mdash;{" "}
          <Link
            className="link"
            to={{
              pathname: "/invoices/details",
              search: `invoiceId=${invoice_id}`,
            }}
          >
            View invoice
          </Link>
        </div>
      </DepositInfoRow>
      <DepositInfoRow>
        <DepositInfoTitle>Reference</DepositInfoTitle>
        <div>{reference}</div>
      </DepositInfoRow>
      <DepositInfoRow>
        <DepositInfoTitle>Created</DepositInfoTitle>
        <div>{formatDateWordTime(created_at)}</div>
      </DepositInfoRow>
      <DepositInfoRow>
        <DepositInfoTitle>Updated</DepositInfoTitle>
        <div>{formatDateWordTime(updated_at)}</div>
      </DepositInfoRow>
      <DepositInfoRow>
        <DepositInfoTitle>Amount</DepositInfoTitle>
        <div>{formatPrice(amount)}</div>
      </DepositInfoRow>
    </DepositInfo>
  );
};

const DepositInfo = styled.div`
  padding-left: 0px;
`;
const DepositInfoRow = styled.div`
  display: flex;
  padding: 4px 10px;
  border-bottom: dashed 1px #eee;
  background: #fffcf777;

  &:last-child {
    border-bottom: 0;
  }
`;
const DepositInfoTitle = styled.div`
  width: 240px;
  text-transform: uppercase;
  font-weight: 700;
  font-size: 13px;
`;

export default Invoice;
