import { DefaultRentPaymentTable, TableRentPayment } from "../atoms";
import { GetOffer_admin_Offer_invoices } from "../../../graphql/queries/__generated__/GetOffer";
import { invoice_api_PaymentStatusEnum as PaymentStatusEnum } from "../../../../../globalTypes";
import { PropertyGrid } from "../../../../../ui/atoms/Property";
import { formatDateWordTime } from "../../../../../util/date";
import { formatPrice } from "../../../../../util/price";
import PaymentStatus from "../../../PaymentStatus";
import React from "react";
import styled from "@emotion/styled";
import theme from "../../../../../ui/theme";

export const StandingOrderTable = ({
  invoice,
  society,
  sort_code,
  account_number,
  frequency,
  monthlyPayment,
  showDefaultTable,
}: {
  invoice: GetOffer_admin_Offer_invoices;
  society: string | undefined;
  sort_code: string | undefined;
  account_number: string | undefined;
  monthlyPayment: number | undefined;
  frequency: number | undefined;
  showDefaultTable: boolean;
}) => {
  const defaultValues = [
    "Bank name",
    "Sort code",
    "Account number",
    "Standing order amount",
    "Frequency",
    "Status",
  ];
  return (
    <BankDetails>
      {!showDefaultTable ? (
        <>
          {invoice.payments?.map((payment) => (
            <TableRentPayment
              defaultValues={defaultValues}
              values={[
                society,
                sort_code,
                account_number,
                monthlyPayment,
                frequency,
                <PaymentStatus
                  key={payment.updated_at}
                  status={payment.status}
                />,
              ]}
            />
          ))}
        </>
      ) : (
        <DefaultRentPaymentTable defaultValues={defaultValues} />
      )}
    </BankDetails>
  );
};

export const FirstRentPaymentTable = ({
  invoice,
  showDefaultTable,
}: {
  invoice: GetOffer_admin_Offer_invoices;
  showDefaultTable: boolean;
}) => {
  const defaultValues = ["Payment method", "Amount", "Paid on", "Status"];
  return (
    <BankDetails>
      {!showDefaultTable ? (
        <>
          {invoice.payments?.map((payment) => {
            const paymentMethod = Object.keys(payment.system.data).filter(
              (key) => payment.system.data[key] != null
            )[0];
            return (
              <TableRentPayment
                defaultValues={defaultValues}
                values={[
                  capitalizeFirstLetter(paymentMethod),
                  formatPrice(invoice.amount),
                  payment.status === PaymentStatusEnum.PAYMENT_SUCCESS
                    ? formatDateWordTime(payment.updated_at)
                    : "- - -",
                  <PaymentStatus
                    key={payment.updated_at}
                    status={payment.status}
                  />,
                ]}
              />
            );
          })}
        </>
      ) : (
        <DefaultRentPaymentTable defaultValues={defaultValues} />
      )}
    </BankDetails>
  );
};

export const DepositReplacementDirectDebitTable = ({
  invoice,
  showDefaultTable,
}: {
  invoice: GetOffer_admin_Offer_invoices;
  showDefaultTable: boolean;
}) => {
  const defaultValues = [
    "Amount",
    "Direct debit payment date",
    "Set up on",
    "Status",
  ];
  return (
    <BankDetails>
      {!showDefaultTable ? (
        <>
          {invoice.payments?.map((payment) => (
            <TableRentPayment
              defaultValues={defaultValues}
              values={[
                formatPrice(invoice.amount),
                payment.status === PaymentStatusEnum.PAYMENT_SUCCESS
                  ? formatDateWordTime(payment.updated_at)
                  : "- - -",
                formatDateWordTime(payment.created_at),
                <PaymentStatus
                  key={payment.updated_at}
                  status={payment.status}
                />,
              ]}
            />
          ))}
        </>
      ) : (
        <DefaultRentPaymentTable defaultValues={defaultValues} />
      )}
    </BankDetails>
  );
};

const capitalizeFirstLetter = (word: string) =>
  word.replace(/(\b\w)/gi, (e) => e.toUpperCase());

const BankDetails = styled(PropertyGrid)`
  padding: 30px 30px 44px;
  background: #f9f6f1;
  border: dashed 2px ${theme.colors.main.lightBlue};
  margin-bottom: 40px;
`;
