import { Link } from "react-router-dom";
import { Td, TdWidth30, Tr } from "../../../../ui/atoms/Table";
import { GetOffer_admin_Offer_viewings as Viewings } from "../../graphql/queries/__generated__/GetOffer";
import {
  formatDate,
  formatDateTimeWithSeconds,
} from "../../../../util/formatters/date";
import { timeFromNumber } from "../../utils";
import React from "react";

type Props = { viewing: Viewings };

const TabViewingItem: React.FC<Props> = ({
  viewing: {
    created_at,
    accepted_at,
    manager,
    feedback,
    sender,
    sender_details,
    time,
  },
}) => (
  <Tr>
    <Td>
      {sender ? (
        <Link className="link" to={`/users/${sender}/view`}>
          {sender_details.first_name}
          &nbsp;
          {sender_details.last_name}
        </Link>
      ) : (
        <>
          {sender_details.first_name}
          &nbsp;
          {sender_details.last_name}
        </>
      )}
    </Td>
    <Td>{formatDateTimeWithSeconds(created_at)}</Td>
    <Td>{formatDateTimeWithSeconds(accepted_at)}</Td>
    <Td>{`${manager?.details?.first_name} ${manager?.details?.last_name}`}</Td>
    <Td>
      {formatDate(time)}
      <br />
      {timeFromNumber(time.time_startsec as number)} –{" "}
      {timeFromNumber(time.time_endsec as number)}
    </Td>
    <TdWidth30>
      {(feedback ?? []).filter((f) => f.comment !== "")?.[0]?.comment}
    </TdWidth30>
  </Tr>
);

export default TabViewingItem;
