import { OFFER_STATUS } from "./constants";
import { GetOffer_admin_Offer as OfferModel } from "./graphql/queries/__generated__/GetOffer";
import {
  offer_api_OfferStateEnum as OfferStateEnum,
  viewing_api_ViewingStateEnum as ViewStatusEnum,
} from "../../globalTypes";
import { OfferStatusTitle, StatusColor } from "./types";
import { OffersList_admin_allOffers_data_tenants } from "./graphql/queries/__generated__/OffersList";

export const getStatus = (
  offer: OfferModel,
  name: OfferStatusTitle
): StatusColor => {
  let color: StatusColor = StatusColor.BLUE;

  if (name === OFFER_STATUS.VIEW) {
    switch (offer.viewing.status) {
      case ViewStatusEnum.VIEWING_STATE_COMPLETED:
      case ViewStatusEnum.VIEWING_STATE_OFFER:
      case ViewStatusEnum.VIEWING_STATE_UNKNOWN:
        color = StatusColor.GREEN;
        break;
      case ViewStatusEnum.VIEWING_STATE_REJECTED:
      case ViewStatusEnum.VIEWING_STATE_CANCELLED:
      case ViewStatusEnum.VIEWING_STATE_FAILED:
        color = StatusColor.RED;
        break;
      default:
        color = StatusColor.YELLOW;
    }
  } else if (name === OFFER_STATUS.OFFER) {
    switch (offer.state) {
      case OfferStateEnum.ERROR:
      case OfferStateEnum.DENIED:
      case OfferStateEnum.CANCELED:
        color = StatusColor.RED;
        break;
      case OfferStateEnum.ACTIVE:
      case OfferStateEnum.PENDING:
        color = StatusColor.YELLOW;
        break;
      default:
        color = StatusColor.GREEN;
    }
  } else if (name === OFFER_STATUS.DEPOSIT) {
    switch (offer.state) {
      case OfferStateEnum.HOLDING_DEPOSIT:
      case OfferStateEnum.AWAITING_CONFIRM:
        color = StatusColor.YELLOW;
        break;
      case OfferStateEnum.DEPOSIT_CONFIRMED:
      case OfferStateEnum.AWAITING_CHECKS:
      case OfferStateEnum.AWAITING_DOCUMENTS:
      case OfferStateEnum.SIGNING:
      case OfferStateEnum.SIGNED:
      case OfferStateEnum.RENTPAID:
      case OfferStateEnum.AWAITING_FEES:
      case OfferStateEnum.AWAITING_CONFIRM_RENT:
      case OfferStateEnum.CHECKING:
      case OfferStateEnum.AWAITING_APPLICANT_CHECK_PAYMENT:
      case OfferStateEnum.AWAITING_GUARANTOR:
      case OfferStateEnum.CONTRACT_PREPARATION:
      case OfferStateEnum.CONTRACT_REVIEW_AND_CLAUSES:
        color = StatusColor.GREEN;
        break;
      default:
        color = StatusColor.BLUE;
    }
  } else if (name === OFFER_STATUS.RENTPROFILE_CHECK) {
    switch (offer.state) {
      case OfferStateEnum.AWAITING_CHECKS:
      case OfferStateEnum.AWAITING_APPLICANT_CHECK_PAYMENT:
      case OfferStateEnum.AWAITING_GUARANTOR:
      case OfferStateEnum.CHECKING:
        color = StatusColor.YELLOW;
        break;
      case OfferStateEnum.AWAITING_DOCUMENTS:
      case OfferStateEnum.SIGNING:
      case OfferStateEnum.SIGNED:
      case OfferStateEnum.RENTPAID:
      case OfferStateEnum.AWAITING_FEES:
      case OfferStateEnum.AWAITING_CONFIRM_RENT:
      case OfferStateEnum.CONTRACT_PREPARATION:
      case OfferStateEnum.CONTRACT_REVIEW_AND_CLAUSES:
        color = StatusColor.GREEN;
        break;
      default:
        color = StatusColor.BLUE;
    }
  } else if (name === OFFER_STATUS.CONTRACT) {
    switch (offer.state) {
      case OfferStateEnum.AWAITING_DOCUMENTS:
      case OfferStateEnum.CONTRACT_PREPARATION:
      case OfferStateEnum.CONTRACT_REVIEW_AND_CLAUSES:
      case OfferStateEnum.SIGNING:
        color = StatusColor.YELLOW;
        break;
      case OfferStateEnum.SIGNED:
      case OfferStateEnum.RENTPAID:
      case OfferStateEnum.AWAITING_FEES:
      case OfferStateEnum.AWAITING_CONFIRM_RENT:
        color = StatusColor.GREEN;
        break;
      default:
        color = StatusColor.BLUE;
    }
  } else if (name === OFFER_STATUS.RENT_PAYMENT) {
    switch (offer.state) {
      case OfferStateEnum.AWAITING_CONFIRM_RENT:
      case OfferStateEnum.AWAITING_FEES:
        color = StatusColor.YELLOW;
        break;
      case OfferStateEnum.RENTPAID:
        color = StatusColor.GREEN;
        break;
      default:
        color = StatusColor.BLUE;
    }
  }

  return color;
};

export const GetFileType = (mime: string): string => {
  const slashIndex = mime.indexOf("/");
  if (slashIndex !== -1) {
    return mime.slice(slashIndex + 1).toUpperCase();
  } else {
    return mime;
  }
};

export const timeFromNumber = (nsec: number) => {
  const n = nsec / 3600;
  return `${`0${Math.floor(n)}`.slice(-2)}:${`0${
    (n - Math.floor(n)) * 60
  }`.slice(-2)}`;
};

export const calcTenantsCheckPrice = (
  tenants: readonly OffersList_admin_allOffers_data_tenants[] | null
) =>
  (tenants
    ? [
        ...tenants,
        ...tenants
          .filter(
            (t) =>
              t.guarantor != null &&
              t.guarantor.email_primary != null &&
              t.guarantor.email_primary !== ""
          )
          .map((t) => t.guarantor),
      ]
    : []
  ).length * 15;
