import { InvoiceTransactionOutputFields } from "../graphql/fragments/__generated__/InvoiceTransactionOutputFields";
import { Link } from "react-router-dom";
import { Td } from "../../../ui/atoms/Table";
import { formatDateTime } from "../../../util/date";
import { formatPrice } from "../../../util/price";
import { sentenceCase } from "change-case";
import React from "react";
import css from "./index.module.css";

export type ListItemProps = {
  transaction: InvoiceTransactionOutputFields;
};

const ListItem: React.FC<ListItemProps> = ({ transaction }) => {
  const hasMatches = (transaction.matches ?? []).length > 0;

  return (
    <tr className={hasMatches ? css.hasMatches : css.notMatches}>
      <Td>{transaction.id}</Td>
      <Td>{transaction.ivr}</Td>
      <Td>{formatDateTime(transaction.created)}</Td>
      <Td>{formatPrice(transaction.amount)}</Td>
      <Td>{transaction.description}</Td>
      <Td>
        <b>{sentenceCase(transaction.type.replace("TRANSACTION_TYPE_", ""))}</b>
      </Td>
      <Td>
        <b>
          {sentenceCase(transaction.status.replace("TRANSACTION_STATUS_", ""))}
        </b>
      </Td>
      <Td>
        <Link
          className="link"
          to={{
            pathname: `/statement/${transaction.id}`,
          }}
        >
          View -&gt;
        </Link>
      </Td>
    </tr>
  );
};

export default ListItem;
