import { PaymentsGetAllInvoices_admin_allInvoices_invoices as Invoice } from "../graphql/queries/__generated__/PaymentsGetAllInvoices";
import { Link } from "react-router-dom";
import { NoWrap, Td, Tr } from "../../../ui/atoms/Table";
import { formatDateTime } from "../../../util/date";
import { formatPrice } from "../../../util/price";
import { invoice_api_InvoiceStatusEnum } from "../../../globalTypes";
import { propertyAddressFilter } from "../../listing/filters";
import { sentenceCase } from "change-case";
import Checkbox from "../../../ui/molecules/Checkbox";
import React, { FC, useMemo } from "react";

export const getInvoiceStatus = (status: invoice_api_InvoiceStatusEnum) => {
  switch (status) {
    case invoice_api_InvoiceStatusEnum.INVOICE_FULFILLED:
      return "Fulfilled";
    case invoice_api_InvoiceStatusEnum.INVOICE_OPEN:
      return "Opened";
    case invoice_api_InvoiceStatusEnum.INVOICE_CANCELED:
      return "Canceled";
    default:
      return sentenceCase(status);
  }
};

export type ListItemProps = {
  invoice: Invoice;
  selectRow(id: string): void;
  selectedRows: string[];
};

const ListItem: FC<ListItemProps> = ({ invoice, selectRow, selectedRows }) => {
  const products = useMemo(() => invoice.order?.products ?? [], [
    invoice.order,
  ]);

  return (
    <Tr
      className={
        selectedRows.includes(invoice.invoice_id) ? "selected-row" : ""
      }
    >
      <Td>
        <Checkbox
          input={{
            onChange: selectRow(invoice.invoice_id),
          }}
        />
      </Td>
      <Td>{invoice.invoice_id}</Td>
      <Td>
        <NoWrap>{invoice.reference}</NoWrap>
      </Td>
      <Td>{formatDateTime(invoice.created_at)}</Td>
      <Td>{formatDateTime(invoice.updated_at)}</Td>
      <Td>
        {products.length > 0 ? (
          <>
            {propertyAddressFilter(products[0].details.property.location)}
            <br />
            {products[0].details.property.id && (
              <Link
                className="link"
                to={`/listing/${products[0].details.property.id}/edit`}
              >
                ...{products[0].details.property.id?.substr(-12)}
              </Link>
            )}
          </>
        ) : (
          "—"
        )}
      </Td>
      <Td>
        {invoice.order?.userid ? (
          <Link className="link" to={`/users/${invoice.order.userid}/view`}>
            {invoice.order.userdata.details.first_name}&nbsp;
            {invoice.order.userdata.details.last_name}
          </Link>
        ) : (
          "—"
        )}
      </Td>
      <Td>
        <b>{formatPrice(invoice.amount)}</b>
      </Td>
      <Td>{getInvoiceStatus(invoice.status)}</Td>
      <Td>
        <Link
          className="link"
          to={{
            pathname: "/invoices/details",
            search: `invoiceId=${invoice.invoice_id}`,
          }}
        >
          View
        </Link>
      </Td>
    </Tr>
  );
};

export default ListItem;
