import { Gap50 } from "../../../ui/atoms/Gap";
import { Link } from "react-router-dom";
import {
  PaymentsGetInvoice,
  PaymentsGetInvoiceVariables,
} from "../graphql/queries/__generated__/PaymentsGetInvoice";
import { PaymentsGroup, PaymentsGroupHead } from "../../../ui/atoms/Payment";
import { Query } from "react-apollo";
import { SecondaryButton } from "../../../ui/atoms/Button";
import DocumentViewer from "./DocumentViewer";
import GET_INVOICE from "../graphql/queries/PaymentsGetInvoice.graphql";
import React from "react";
import Spinner from "../../../ui/atoms/Spinner";
import SystemError from "../../../ui/atoms/SystemError";
import ViewItem from "./ViewItem";

const InvoiceDetails = ({ location }) => {
  const params = new URLSearchParams(location.search);
  const invoiceIds = params.getAll("invoiceId");

  return (
    <PaymentsGroup>
      <PaymentsGroupHead>
        <Link className="link-button" to="/invoices">
          <SecondaryButton>Back</SecondaryButton>
        </Link>
        <h2>Invoices</h2>
      </PaymentsGroupHead>

      {invoiceIds.map((id, index) => (
        <React.Fragment key={id}>
          <Query<PaymentsGetInvoice, PaymentsGetInvoiceVariables>
            query={GET_INVOICE}
            variables={{
              invoice_id: id,
            }}
          >
            {({ data, loading, error, refetch }) => {
              if (error) {
                return <SystemError error={error} />;
              } else if (loading) {
                return <Spinner />;
              }

              const invoice = data?.admin?.Invoice;

              if (!invoice) {
                return null;
              }

              return (
                <>
                  <ViewItem
                    invoice={invoice}
                    isOpenedItem={index === 0}
                    onComplete={() => refetch()}
                  />
                  <DocumentViewer invoice={invoice} />
                </>
              );
            }}
          </Query>
        </React.Fragment>
      ))}
      <Gap50 />
    </PaymentsGroup>
  );
};

export default InvoiceDetails;
