import {
  PaymentsGetAllScheduledPayments_admin_allScheduledPayments_data as AllScheduledPayments,
  PaymentsGetAllScheduledPayments_admin_allScheduledPayments_data_parts_payment as AllScheduledPayments_data_parts_payment,
} from "../../graphql/queries/__generated__/PaymentsGetAllScheduledPayments";
import {
  ColumnTitle,
  ColumnValue,
  PaymentBody,
  PaymentClose,
  PaymentConfirmed,
  PaymentDescription,
  PaymentHead,
  PaymentOpen,
  PaymentRow,
} from "../../../../ui/atoms/Payment";
import { PaymentsGetOfferForTenancy_admin_Offer } from "../../graphql/queries/__generated__/PaymentsGetOfferForTenancy";
import { PaymentsGetProperty_admin_Property } from "../../graphql/queries/__generated__/PaymentsGetProperty";
import { formatDate } from "../../../../util/date";
import { formatPrice } from "../../../../util/price";
import { offer_api_DepositTypeEnum } from "../../../../globalTypes";
import Collapse from "../../../../ui/molecules/Collapse";
import DepositRegistration from "./DepositRegistration";
import Payment from "./Payment";
import Payout from "./Payout";
import React, { FC, useMemo } from "react";
import Reconciliation from "./Reconciliation";
import css from "./index.module.css";

type Props = {
  scheduledItem: AllScheduledPayments | undefined;
  payment: AllScheduledPayments_data_parts_payment | null | undefined;
  offer: PaymentsGetOfferForTenancy_admin_Offer;
  property: PaymentsGetProperty_admin_Property;
};

const MoveinPayments: FC<Props> = ({
  scheduledItem: tenantServicesScheduled,
  payment: tenantServicesPayment,
  offer,
  property,
}) => {
  const { invoices } = offer;

  const isDRP =
    offer.conditions.deposit_type ===
    offer_api_DepositTypeEnum.DEPOSIT_REPLACEMENT;

  const standingOrderInvoice = useMemo(
    () => invoices.find((s) => s.correlation_target === "standing-order"),
    [invoices]
  );
  const tenantServicesInvoice = useMemo(
    () => invoices.find((s) => s.correlation_target === "tenant-services"),
    [invoices]
  );
  const holdingDepositInvoice = useMemo(
    () => invoices.find((s) => s.correlation_target === "holding-deposit"),
    [invoices]
  );
  const depositPrice = useMemo(() => {
    if (isDRP) {
      return invoices.find(
        (s) => s.correlation_target === "deposit-replacement"
      )?.amount;
    }
    const service = (tenantServicesInvoice?.services ?? []).find(
      (s) => s.service.code === "traditional_deposit"
    );
    if (service) {
      return service.service.price + service.service.tax_amount;
    } else {
      return null;
    }
  }, [isDRP, invoices, tenantServicesInvoice]);
  const landlordTotalAmount = useMemo(
    () =>
      (standingOrderInvoice?.amount ?? 0) +
      (tenantServicesPayment?.amount ?? 0),
    [standingOrderInvoice, tenantServicesPayment]
  );

  return (
    <Collapse opened={true}>
      {({ toggle, isOpened }) => (
        <PaymentConfirmed>
          <PaymentHead>
            {isOpened ? (
              <PaymentClose onClick={toggle} />
            ) : (
              <PaymentOpen onClick={toggle} />
            )}
            <PaymentDescription>
              <b>Move in payments</b>
            </PaymentDescription>
          </PaymentHead>

          {isOpened && (
            <PaymentBody className={css.pageContent}>
              <h3 className={css.subTitle}>
                First rent instalment and deposit payment
              </h3>
              <PaymentRow>
                <div className={css.columnHead}>
                  <ColumnTitle>Due date</ColumnTitle>
                  <ColumnValue>
                    {tenantServicesPayment
                      ? formatDate(tenantServicesPayment.scheduled_at)
                      : "—"}
                  </ColumnValue>
                </div>
                <div className={css.columnHead}>
                  <ColumnTitle>Holding deposit</ColumnTitle>
                  <ColumnValue>
                    {formatPrice(holdingDepositInvoice?.amount)}
                  </ColumnValue>
                </div>
                <div className={css.columnHead}>
                  <ColumnTitle>Deposit amount</ColumnTitle>
                  <ColumnValue>{formatPrice(depositPrice)}</ColumnValue>
                </div>
                <div className={css.columnHead}>
                  <ColumnTitle>Amount owed to landlord</ColumnTitle>
                  <ColumnValue>{formatPrice(landlordTotalAmount)}</ColumnValue>
                </div>
              </PaymentRow>

              {offer && (
                <Payment
                  depositPrice={depositPrice}
                  holdingDepositInvoice={holdingDepositInvoice}
                  isDRP={isDRP}
                  offer={offer}
                  payment={tenantServicesPayment}
                  paymentIdx={1}
                  standingOrderInvoice={standingOrderInvoice}
                />
              )}

              {tenantServicesPayment && (
                <Reconciliation
                  ivr={property.ivr}
                  payment={tenantServicesPayment}
                />
              )}

              {tenantServicesPayment && tenantServicesScheduled && offer && (
                <Payout
                  ivr={property.ivr}
                  offer={offer}
                  payment={tenantServicesPayment}
                  scheduledPayment={tenantServicesScheduled}
                />
              )}

              {tenantServicesPayment && offer && (
                <DepositRegistration
                  isDRP={isDRP}
                  offer={offer}
                  propertyId={property.id}
                />
              )}
            </PaymentBody>
          )}
        </PaymentConfirmed>
      )}
    </Collapse>
  );
};

export default MoveinPayments;
