import { Link } from "react-router-dom";
import {
  PaymentsGetUser,
  PaymentsGetUserVariables,
} from "./graphql/queries/__generated__/PaymentsGetUser";
import { Query } from "react-apollo";
import { oc } from "ts-optchain";
import GET_USER from "./graphql/queries/PaymentsGetUser.graphql";
import React from "react";
import SystemError from "../../ui/atoms/SystemError";

const UserInfo = ({ userId }: { userId: string }) => (
  <Query<PaymentsGetUser, PaymentsGetUserVariables>
    query={GET_USER}
    variables={{ id: userId }}
  >
    {({ data, loading, error }) => {
      if (error) {
        return <SystemError error={error} />;
      } else if (loading) {
        return <>loading...</>;
      }

      const user = oc(data).admin.User();

      if (!user) {
        return null;
      }

      return (
        <Link
          className="link"
          to={user.admin ? `/admin/${user.id}/edit` : `/users/${user.id}/view`}
        >
          {user!.details!.first_name}&nbsp;{user!.details!.last_name}
        </Link>
      );
    }}
  </Query>
);

export default UserInfo;
