import {
  CreatePayment,
  CreatePaymentVariables,
} from "../payments/graphql/mutations/__generated__/CreatePayment";
import { Link } from "react-router-dom";
import {
  PayoutsInvoicesOutputFields_property_data_bank_details,
  PayoutsInvoicesOutputFields_property_data_people_landlord_details,
} from "./graphql/fragments/__generated__/PayoutsInvoicesOutputFields";
import { PrimaryButton } from "../../ui/atoms/Button";
import { Td, Tr } from "../../ui/atoms/Table";
import { addDays } from "date-fns";
import { formatDateTime } from "../../util/date";
import { invoice_api_PaymentStatusEnum } from "../../globalTypes";
import { useMutation } from "react-apollo";
import CREATE_PAYMENT from "../payments/graphql/mutations/CreatePayment.graphql";
import React, { FC } from "react";
import styled from "@emotion/styled";

export type ListItemProps = {
  address: string | null | undefined;
  amount: number | undefined;
  created_at: string;
  landlord_details:
    | PayoutsInvoicesOutputFields_property_data_people_landlord_details
    | null
    | undefined;
  bank_details:
    | PayoutsInvoicesOutputFields_property_data_bank_details
    | null
    | undefined;
  invoice_id: string;
  updated_at: string;
  type: string;
  propertyId: string | undefined;
};

const ListItem: FC<ListItemProps> = ({
  address,
  amount,
  created_at,
  landlord_details,
  bank_details,
  invoice_id,
  updated_at,
  type,
  propertyId,
}) => {
  const [createPayment, { loading: createPaymentLoading }] = useMutation<
    CreatePayment,
    CreatePaymentVariables
  >(CREATE_PAYMENT);

  const handleUpdateStatus = async (invoice_id: string) => {
    await createPayment({
      variables: {
        invoice_id,
        status: invoice_api_PaymentStatusEnum.PAYMENT_SUCCESS,
      },
      refetchQueries: ["PayoutsGetAllInvoices"],
    });
  };

  return (
    <Tr>
      <Td>
        <Link className="link" to={`/listing/${propertyId}/edit`}>
          {address}
        </Link>
      </Td>
      <Td>{landlord_details?.first_name}</Td>
      {/* <Td>{submitter_details?.first_name}</Td> */}
      <Td>{formatDateTime(created_at)}</Td>
      <Td>{formatDateTime(addDays(new Date(updated_at), 1))}</Td>
      <Td>{amount}</Td>
      <Td>{type === "rent-payout" ? "RENT" : "other"}</Td>
      <Td>
        {bank_details?.account_name}
        {(bank_details?.sort_code || bank_details?.account_number) && (
          <>
            <br />
            {bank_details?.sort_code} | {bank_details?.account_number}
          </>
        )}
        {bank_details?.personal_reference && (
          <>
            <br />
            {bank_details?.personal_reference}
          </>
        )}
      </Td>
      <Td colSpan={2}>
        <ButtonMark
          onClick={() => {
            handleUpdateStatus(invoice_id);
          }}
          type="button"
        >
          {createPaymentLoading ? "loading" : "Mark as paid"}
        </ButtonMark>
      </Td>
    </Tr>
  );
};

const ButtonMark = styled(PrimaryButton)`
  width: 100%;
`;

export default ListItem;
