import { Field, Form } from "react-final-form";
import { Modal } from "../../../ui/molecules/Modal";
import { PrimaryButton, SecondaryButton } from "../../../ui/atoms/Button";
import {
  UpdateUser,
  UpdateUserVariables,
} from "../graphql/mutations/__generated__/UpdateUser";
import { UserFormRow } from "../../../ui/atoms/UserForm";
import { required } from "../../../util/validations";
import { useMutation } from "react-apollo";
import CountryPhoneInput from "../../../ui/atoms/PhoneInput";
import ErrorMessage from "../../../ui/molecules/ErrorMessage";
import React, { FC } from "react";
import UPDATE_USER from "../graphql/mutations/updateUser.graphql";
import css from "./index.module.css";

interface FormValues {
  phone: string;
}

type Props = {
  userId: string;
  onCancel: () => void;
  onSubmit: () => void;
};

const ChangePhoneNumberModal: FC<Props> = ({ userId, onCancel, onSubmit }) => {
  const [updateUserInfo, { loading }] = useMutation<
    UpdateUser,
    UpdateUserVariables
  >(UPDATE_USER);

  function handleSubmit(values: FormValues) {
    updateUserInfo({
      variables: {
        account: {
          id: userId,
          contact: {
            phone_primary: values.phone,
          },
        },
      },
    }).then((res) => res.data?.admin?.updateUser && onSubmit());
  }

  return (
    <Modal onCancel={onCancel} title="Change phone number" withoutOverflow>
      <Form<FormValues>
        onSubmit={handleSubmit}
        render={({ handleSubmit, hasValidationErrors }) => (
          <form onSubmit={handleSubmit}>
            <UserFormRow>
              <label>New phone number</label>
              <Field<string>
                name="phone"
                render={({ input }) => <CountryPhoneInput input={input} />}
                validate={required("Value is required")}
              />
              <Field component={ErrorMessage} name="password" />
            </UserFormRow>

            <div className={css.actionButtons}>
              <SecondaryButton onClick={onCancel} type="button">
                Cancel
              </SecondaryButton>
              <PrimaryButton disabled={hasValidationErrors || loading}>
                Save
              </PrimaryButton>
            </div>
          </form>
        )}
      />
    </Modal>
  );
};

export default ChangePhoneNumberModal;
