import { FETCH_USER_NOTIFICATIONS } from "./UserDetails/Notifications";
import {
  FetchUserNotifications,
  FetchUserNotificationsVariables,
} from "./UserDetails/__generated__/FetchUserNotifications";
import { PrimaryButton, SecondaryButton } from "../../ui/atoms/Button";
import { RouteComponentProps, useHistory } from "react-router-dom";
import { SetReminderModal } from "../../components/SetReminderModal/SetReminderModal";
import { UserFormAction, UserFormWrapper } from "../../ui/atoms/UserForm";
import { UserInfoHeader, UserInform } from "../../ui/atoms/UserCard";
import {
  common_api_generic_query_QueryFilterOperatorEnum,
  notes_api_CorrelationTypeEnum,
} from "../../globalTypes";
import { useQuery } from "react-apollo";
import ChangePasswordModal from "../../components/ChangePasswordModal/ChangePasswordModal";
import React, { useCallback, useMemo, useState } from "react";
import SendSMSModal from "./SendSMSModal";
import UserDetails from "./UserDetails";
import styled from "@emotion/styled";

type ParamsProps = {
  id: string;
};
type Props = RouteComponentProps<ParamsProps>;

const Details = (props: Props) => {
  const history = useHistory();
  const [showModal, setShowModal] = useState<
    null | "send-sms" | "change-password" | "reminder"
  >(null);

  const handleCancelModal = () => setShowModal(null);

  const userId = props.match.params.id;

  const handleChangePassword = useCallback(() => {
    setShowModal("change-password");
  }, []);

  const handleOpenReminderModal = useCallback(
    () => setShowModal("reminder"),
    []
  );

  const handleViewReminders = useCallback(() => {
    history.push(`/users/${userId}/view/notifications`);
  }, [history, userId]);

  const { data: reminders } = useQuery<
    FetchUserNotifications,
    FetchUserNotificationsVariables
  >(FETCH_USER_NOTIFICATIONS, {
    variables: {
      pagination: { page: 1, perPage: 100 },
      filter: [
        {
          fields: ["correlation_type"],
          value: [notes_api_CorrelationTypeEnum.CORRELATION_TYPE_USER],
          operator: common_api_generic_query_QueryFilterOperatorEnum.EQUALS,
        },
        {
          fields: ["correlation_id"],
          value: [userId],
          operator: common_api_generic_query_QueryFilterOperatorEnum.EQUALS,
        },
      ],
    },
  });

  const hasReminders = useMemo(
    () => !!reminders?.admin?.allNotes?.notes?.length,
    [reminders]
  );

  return (
    <UserInform>
      {showModal === "send-sms" ? (
        <SendSMSModal onCancel={handleCancelModal} />
      ) : showModal === "change-password" ? (
        <ChangePasswordModal
          onCancel={handleCancelModal}
          onSubmit={handleCancelModal}
          userId={userId!}
        />
      ) : showModal === "reminder" ? (
        <SetReminderModal
          onCancel={handleCancelModal}
          onSubmit={handleCancelModal}
          userId={userId!}
        />
      ) : null}

      <UserInfoHeader>
        <h2>Platform User Details</h2>
        <PrimaryButton onClick={handleOpenReminderModal} style={{ height: 40 }}>
          Set reminder
        </PrimaryButton>
      </UserInfoHeader>
      <UserFormWrapper>
        {hasReminders && (
          <RemindersButton onClick={handleViewReminders}>
            View reminders
          </RemindersButton>
        )}
        <UserDetails userId={userId} />
        <ActionRow>
          <SecondaryButton onClick={() => history.push("/users")}>
            <span className="material-icons" style={{ marginRight: "6px" }}>
              keyboard_backspace
            </span>
            Back
          </SecondaryButton>
          <PrimaryButton onClick={handleChangePassword}>
            Change Password
          </PrimaryButton>
        </ActionRow>
      </UserFormWrapper>
    </UserInform>
  );
};

const RemindersButton = styled(SecondaryButton)`
  position: absolute;
  top: -1px;
  right: 10px;
  width: 165px;
`;

const ActionRow = styled(UserFormAction)`
  flex-direction: row;
  justify-content: space-between;
  margin: 0 -15px;

  > button {
    width: calc(50% - 16px);
    height: 40px;
  }
`;

export default Details;
