import { CheckboxConfirm } from "../../ui/atoms/CheckboxInput";
import { Field, Form } from "react-final-form";
import { Modal } from "../../ui/molecules/Modal";
import { PrimaryButton, SecondaryButton } from "../../ui/atoms/Button";
import { UserFormAction, UserFormRow } from "../../ui/atoms/UserForm";
import { required } from "../../util/validations";
import ErrorMessage from "../../ui/molecules/ErrorMessage";
import React, { FC } from "react";
import Textarea from "../../ui/atoms/Textarea";

type Props = {
  onCancel: () => void;
};

const SendSMSModal: FC<Props> = ({ onCancel }) => {
  const handleSubmit = () => {
    //console.log(values);
  };

  return (
    <Modal onCancel={onCancel}>
      <Form
        onSubmit={handleSubmit}
        render={({ handleSubmit, values, valid, submitting }) => (
          <form onSubmit={handleSubmit}>
            <UserFormRow>
              <Field
                name="message"
                render={({ input, meta }) => {
                  return (
                    <>
                      <Textarea
                        cols={40}
                        rows={5}
                        {...input}
                        className={
                          meta.error && meta.touched ? "input-error" : ""
                        }
                      />
                      <Field component={ErrorMessage} name="message" />
                    </>
                  );
                }}
                validate={required("Value is required")}
              />
            </UserFormRow>
            <UserFormRow>
              <Field
                name="confirm"
                render={({ input }) => (
                  <CheckboxConfirm>
                    <input type="checkbox" {...input} />
                    <span>I confirm sending of the SMS</span>
                  </CheckboxConfirm>
                )}
                type="checkbox"
              />
            </UserFormRow>
            <UserFormAction>
              <SecondaryButton onClick={onCancel} type="button">
                Cancel
              </SecondaryButton>
              <PrimaryButton disabled={!values.confirm || !valid || submitting}>
                Send
              </PrimaryButton>
            </UserFormAction>
          </form>
        )}
      />
    </Modal>
  );
};

export default SendSMSModal;
