import {
  UserDetails as Col,
  UserItemName as Name,
  UserFlexRow as Row,
  UserItemValue as Value,
} from "../../../ui/atoms/UserCard";
import { GetUserInfo_admin_User_bank_details } from "../graphql/queries/__generated__/GetUserInfo";
import { UserFormGroup as Group } from "../../../ui/atoms/UserForm";
import { PrimaryButton } from "../../../ui/atoms/Button";
import ChangeBankDetailsModal from "../ChangeBankDetailsModal";
import React, { FC, useState } from "react";

type Props = {
  bankDetails: GetUserInfo_admin_User_bank_details | null | undefined;
  onComplete: () => void;
  userId: string | undefined;
};

const BankDetails: FC<Props> = ({ bankDetails, onComplete, userId }) => {
  const [showModal, setShowModal] = useState(false);

  if (!bankDetails || !userId) {
    return null;
  }

  const { account_number, account_name, society, sort_code } = bankDetails;

  return (
    <>
      <Group>
        <h3>Bank details</h3>
        <Row>
          <Col>
            <Name>Account name</Name>
            <Value>{account_name || "N/A"}</Value>
          </Col>
          <Col>
            <PrimaryButton onClick={() => setShowModal(true)}>
              Change
            </PrimaryButton>
          </Col>
        </Row>
        <Row>
          <Col>
            <Name>Account number</Name>
            <Value>{account_number || "N/A"}</Value>
          </Col>
        </Row>
        <Row>
          <Col>
            <Name>Society</Name>
            <Value>{society || "N/A"}</Value>
          </Col>
        </Row>
        <Row>
          <Col>
            <Name>Sort code</Name>
            <Value>{sort_code || "N/A"}</Value>
          </Col>
        </Row>
      </Group>

      {showModal && (
        <ChangeBankDetailsModal
          bankDetails={bankDetails}
          onCancel={() => setShowModal(false)}
          onSubmit={() => {
            setShowModal(false);
            onComplete();
          }}
          userId={userId}
        />
      )}
    </>
  );
};

export default BankDetails;
