import { Product } from "./types";
import { StatusActive, StatusBlock } from "../../ui/atoms/Status";
import { TaxTypeOptions } from "./constanst";
import { Td, Tr } from "../../ui/atoms/Table";
import React, { memo } from "react";
import css from "./index.module.css";

type ListItemProps = {
  product: Product;
  onOpenDetailsClick: (product: Product) => void;
};

const ProductRow = memo(({ product, onOpenDetailsClick }: ListItemProps) => {
  return (
    <Tr key={product.id}>
      <Td>
        {!product.cart_product ? (
          <StatusBlock>╳</StatusBlock>
        ) : (
          <StatusActive>✔</StatusActive>
        )}
      </Td>
      <Td>{product.title}</Td>
      <Td>{product.price} </Td>
      <Td>{product.tax_amount}</Td>
      <Td>
        {TaxTypeOptions.find((el) => el.value === product.tax_type)?.label}
      </Td>
      <Td>
        <span
          className={css.link}
          onClick={() => onOpenDetailsClick(product)}
          role="button"
          tabIndex={0}
        >
          Open
        </span>
      </Td>
    </Tr>
  );
});

export default ProductRow;
