import { PrimaryButton } from "../../ui/atoms/Button";
import { Product } from "./types";
import { ProductTypeOptions, RoleOptions, TaxTypeOptions } from "./constanst";
import { StatusActive, StatusBlock } from "../../ui/atoms/Status";
import React from "react";
import css from "./index.module.css";

type Props = {
  product: Product;
  onEditClick: () => void;
};
const ViewProduct = ({ product, onEditClick }: Props) => {
  return (
    <div className={css.viewWrapper}>
      <div className={css.editButtonWrapper}>
        <PrimaryButton onClick={onEditClick}>Edit</PrimaryButton>
      </div>
      <div className={css.row}>
        <div className={css.field}>
          <span>Title</span>
          <p>{product.title}</p>
        </div>
      </div>
      <div className={css.row}>
        <div className={css.field}>
          <span>Code</span>
          <p>{product.code}</p>
        </div>
      </div>
      <div className={css.row}>
        <div className={css.field}>
          <span>Description</span>
          <p>
            {product.description
              ? product.description
              : "No description available"}
          </p>
        </div>
      </div>
      <div className={css.row}>
        <div className={css.field}>
          <span>Cart product</span>
          <p>
            {!product.cart_product ? (
              <StatusBlock>╳</StatusBlock>
            ) : (
              <StatusActive>✔</StatusActive>
            )}
          </p>
        </div>
        <div className={css.field}>
          <span>Product type</span>
          <p>
            {ProductTypeOptions.find((el) => el.value === product.type)?.label}
          </p>
        </div>
        <div className={css.field}>
          <span>Role</span>
          <p>{RoleOptions.find((el) => el.value === product.role)?.label}</p>
        </div>
      </div>
      <div className={css.row}>
        <div className={css.field}>
          <span>Price</span>
          <p>{product.price}</p>
        </div>
        <div className={css.field}>
          <span>Tax amount</span>
          <p>{product.tax_amount ?? " - "}</p>
        </div>
        <div className={css.field}>
          <span>Tax type</span>
          <p>
            {TaxTypeOptions.find((el) => el.value === product.tax_type)?.label}
          </p>
        </div>
      </div>
      <div className={css.row}>
        <div className={css.field}>
          <span>Main icon url </span>
          <p>{product.main_icon_url}</p>
        </div>
        <div className={css.field}>
          <span>Page url </span>
          <p>{product.page_url}</p>
        </div>
      </div>
    </div>
  );
};
export default ViewProduct;
