import { css } from "@emotion/core";
import styled from "@emotion/styled";
import theme from "../theme";

export const PaymentsGroup = styled.div`
  max-width: 800px;
  margin: auto;
`;
export const PaymentsGroupHead = styled.div`
  margin: 0 0 30px;
  position: relative;
  text-align: center;

  a {
    position: absolute;
    left: 0;
    top: 0;
  }
`;
export const Payment = styled.div`
  margin: 0 0 10px;
  border-radius: 5px;
  background: white;
`;
export const PaymentSubmitted = styled(Payment)`
  border: solid 1px ${theme.colors.main.orange};
`;
export const PaymentConfirmed = styled(Payment)`
  border: solid 1px ${theme.colors.main.green};
`;
export const StatusConfirmed = styled.div`
  width: 20px;
  height: 20px;
  border-radius: 20px;
  background: ${theme.colors.main.green};
`;
export const StatusSubmitted = styled(StatusConfirmed)`
  background: ${theme.colors.main.orange};
`;
export const StatusError = styled(StatusConfirmed)`
  background: ${theme.colors.main.red};
`;
export const Status = styled(StatusConfirmed)<{
  status: "danger" | "warning" | "success" | "default" | "info";
}>`
  ${({ status }) =>
    status === "danger"
      ? css`
          background: ${theme.colors.main.red};
        `
      : status === "warning"
      ? css`
          background: ${theme.colors.main.orange};
        `
      : status === "success"
      ? css`
          background: ${theme.colors.main.green};
        `
      : status === "info"
      ? css`
          background: ${theme.colors.main.darkGrey};
        `
      : status === "default"
      ? css`
          background: ${theme.colors.main.midGrey};
        `
      : ""}
`;

export const PaymentHead = styled.div`
  position: relative;
  padding: 20px 0;
  margin: 0 20px 0 60px;
  display: flex;
  align-items: center;
`;

export const PaymentOpen = styled.div`
  position: absolute;
  width: 50px;
  height: 50px;
  background: rgba(0, 0, 0, 0);
  top: 50%;
  right: 100%;
  transform: translate(-5px, -50%);
  cursor: pointer;

  &:before {
    content: "";
    width: 10px;
    height: 10px;
    border-bottom: solid 2px ${theme.colors.main.mainGrey};
    border-right: solid 2px ${theme.colors.main.mainGrey};
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    bottom: 6px;
    margin: auto;
    transform: rotate(45deg);
  }
`;
export const PaymentClose = styled(PaymentOpen)`
  &:before {
    transform: rotate(-135deg);
    border-bottom: solid 2px ${theme.colors.main.mainBlue};
    border-right: solid 2px ${theme.colors.main.mainBlue};
    top: 6px;
    bottom: 0;
  }
`;
export const PaymentBody = styled.div`
  padding: 20px 0;
  margin: -1px 20px 0 60px;
  border-top: solid 1px ${theme.colors.main.midGrey};
`;
export const PaymentRow = styled.div`
  display: flex;
  flex-wrap: wrap;
  justify-content: space-between;
`;
export const PaymentCreatedAt = styled.time`
  font-size: 14px;
  width: 33%;
`;
export const PaymentDescription = styled.time`
  font-size: 16px;
  flex: 1;
  padding-right: 20px;
  font-weight: 500;
`;
export const PaymentAmount = styled.time`
  font-size: 16px;
  font-weight: 700;
  width: 16%;
  margin-left: auto;
`;
export const ColumnWide = styled.div`
  width: 67%;
  margin-bottom: 25px;
  padding-right: 20px;
`;
export const ColumnNarrow = styled.div`
  width: 33%;
  margin-bottom: 25px;
`;
export const ColumnTitle = styled.div`
  text-transform: uppercase;
  font-size: 12px;
  margin: 0 0 8px;
  font-weight: 700;
`;
export const ColumnValue = styled.div`
  font-size: 14px;
  line-height: 1.88;
`;
export const Actions = styled.div`
  width: 100%;
  display: flex;
  justify-content: center;
  padding: 10px 0;
`;
export const ConfirmedDetails = styled.div`
  display: flex;
  padding: 20px 20px 1px 60px;
  background: ${theme.colors.main.lightGrey};
  border-top: dashed 2px ${theme.colors.main.midGrey};
  width: calc(100% + 80px);
  margin: 0 -20px -20px -60px;
  border-radius: 0 0 5px 5px;
`;
export const DownloadPayment = styled.div`
  margin-bottom: 20px;

  button {
    padding: 0 20px;
    margin: 0 10px;
  }
`;
export const ImagesGroup = styled.div`
  display: flex;
  flex-wrap: wrap;
  width: calc(100% + 10px);
  position: relative;
  padding: 20px 0 0;

  &::before {
    content: "";
    position: absolute;
    top: 0;
    left: 5px;
    right: 5px;
    border-top: solid 1px #d8d8d8;
  }
`;

export const Image = styled.img`
  width: 100%;
  height: 100%;
  object-fit: contain;
`;

export const ImageAnchor = styled.a`
  width: calc(25% - 10px);
  height: 100px;
  margin: 0 5px 10px;
  border: solid 1px #d8d8d8;
  box-shadow: inset 0 0 0 1px white;
  display: block;
  text-decoration: none;
`;
