import { CopyToClipboard } from "react-copy-to-clipboard";
import { keyframes } from "@emotion/core";
import IconCopied from "../assets/IconCopied";
import React, { FC, useEffect, useState } from "react";
import styled from "@emotion/styled";
import theme from "../theme";

export type CopyTextProps = {
  text?: string;
  textForCopy: string;
};

const TIMEOUT = 2000;

const CopyText: FC<CopyTextProps> = ({ textForCopy, text, children }) => {
  const [copied, setCopied] = useState<boolean>(false);
  useEffect(() => {
    let timer;

    if (copied) {
      timer = setTimeout(() => {
        setCopied(false);
      }, TIMEOUT);
    }

    return () => {
      if (timer) {
        clearTimeout(timer);
        timer = null;
      }
    };
  }, [copied]);
  const handleCopy = () => {
    setCopied(true);
  };

  return (
    <CopyToClipboard onCopy={handleCopy} text={textForCopy}>
      {copied ? (
        <Copied>
          Copied!&nbsp;
          <IconCopied />
        </Copied>
      ) : children ? (
        children
      ) : (
        <Copy>{text ? text : "Copy"}</Copy>
      )}
    </CopyToClipboard>
  );
};

const hide_msg = keyframes`
  0% {
    opacity: 1;
  }
  35% {
    opacity: 1;
  }
  100% {
    opacity: 0;
  }
`;

const show_msg = keyframes`
  from {
    opacity: 0;
  }
  to {
    opacity: 1;
  }
`;

const Copy = styled.span`
  margin: 0 0 0 12px;
  font-weight: 700;
  cursor: pointer;
  color: ${theme.colors.main.orange};
  opacity: 0;
  animation: ${show_msg} 1 0.15s forwards;
`;

const Copied = styled.span`
  color: ${theme.colors.main.green};
  margin: 0 0 0 12px;
  animation: ${hide_msg} 1 1.8s forwards;
  font-weight: 500;

  svg {
    position: absolute;
    margin-top: 0.71em;
    transform: translateY(-50%);
  }
`;

export default CopyText;
