import { common_api_generic_query_QueryParamsFilterInput } from "../../globalTypes";
import { useEffect, useState } from "react";

const defaultPerPage = 25;

type Props = {
  curPage?: number;
  perPage?: number;
} & { filter?: common_api_generic_query_QueryParamsFilterInput[] };

type PaginationProps = Props & {
  children: (v: {
    page: number;
    perPage: number;
    setPage: (v: number) => void;
    setPerPage: (v: number) => void;
  }) => JSX.Element;
};

const Pagination = (props: PaginationProps) => {
  const { page, setPage, perPage, setPerPage } = usePagination(props);

  useEffect(() => {
    if (props.filter) {
      setPage(1);
    }
  }, [props.filter, setPage, props]);

  return props.children({
    page,
    setPage,
    perPage,
    setPerPage,
  });
};

export const usePagination = ({ curPage, perPage, filter }: Props) => {
  const [page, setPage] = useState(curPage ?? 1);
  const [itemsPerPage, setPerPage] = useState(perPage ?? defaultPerPage);

  useEffect(() => {
    if (filter && filter.length > 0) {
      setPage(1);
    }
  }, [filter, setPage]);

  return {
    page,
    setPage,
    perPage: itemsPerPage,
    setPerPage,
  };
};

export default Pagination;
