import { TextInput } from "../atoms/Input";
import ErrorMessage from "./ErrorMessage";
import PasswordInputWrapper from "../atoms/PasswordInputWrapper";
import React, { useState } from "react";
import TextHint from "../atoms/TextHint";
import styled from "@emotion/styled";
import theme from "../theme";

const PasswordField = ({ meta, input, textHint }: any) => {
  const [isPasswordVisible, toggleVisibility] = useState(false);
  const toggle = () => toggleVisibility(!isPasswordVisible);

  return (
    <>
      <PasswordInputWrapper>
        <input type="hidden" value="password" />
        <TextInput
          className={meta.error && meta.touched ? "input-error" : ""}
          {...input}
          type={isPasswordVisible ? "text" : "password"}
        />
        <Icon onClick={toggle}>
          <span className="material-icons">
            {isPasswordVisible ? "visibility_off" : "visibility"}
          </span>
        </Icon>
      </PasswordInputWrapper>
      <ErrorMessage meta={meta} />
      {textHint && <TextHint>{textHint}</TextHint>}
    </>
  );
};

const Icon = styled.div`
  position: absolute;
  right: 2px;
  top: 2px;
  bottom: 2px;
  border-radius: 5px;
  z-index: 1;
  background: rgba(255, 255, 255, 0);
  display: flex;
  align-items: center;
  justify-content: center;
  cursor: pointer;
  color: ${theme.colors.icons.lightBlue1};
  transition: all 0.25s;
  width: 40px;
  user-select: none;

  &:hover {
    color: ${theme.colors.icons.darkBlue};
  }
`;

export default PasswordField;
