import {
  invoice_api_InvoiceStatusEnum as InvoiceStatus,
  invoice_api_PaymentStatusEnum as PaymentStatus,
} from "../globalTypes";
import { PaymentsGetInvoice_admin_Invoice } from "../entities/payments/graphql/queries/__generated__/PaymentsGetInvoice";

const getInvoicePaymentStatus = (
  invoice:
    | Pick<PaymentsGetInvoice_admin_Invoice, "status" | "payments">
    | undefined
): string => {
  if (!invoice) {
    return PaymentStatus.UNKNOWN_PAYMENT_STATUS;
  }

  if (invoice.status === InvoiceStatus.INVOICE_FULFILLED) {
    return PaymentStatus.PAYMENT_SUCCESS;
  }

  if (invoice.payments && invoice.payments.length === 0) {
    return PaymentStatus.UNKNOWN_PAYMENT_STATUS;
  }

  if (
    invoice.payments?.some(
      (payment) => payment.status === PaymentStatus.PAYMENT_FAILED
    )
  ) {
    return PaymentStatus.PAYMENT_FAILED;
  }

  if (
    invoice.payments?.some(
      (payment) => payment.status === PaymentStatus.PAYMENT_CONFIRM
    )
  ) {
    return PaymentStatus.PAYMENT_CONFIRM;
  }

  return PaymentStatus.PAYMENT_PENDING;
};

export default getInvoicePaymentStatus;
